/*
 * Copyright (c) 2005 Henri Sivonen
 * Copyright (c) 2008 Mozilla Foundation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 */

package nu.validator.htmlparser.impl;

import nu.validator.htmlparser.annotation.NoLength;

/**
 * @version $Id: NamedCharacters.java 455 2008-09-29 07:00:58Z hsivonen $
 * @author hsivonen
 */
public final class NamedCharacters {
    static final char[][] NAMES = { "AElig".toCharArray(),
            "AElig;".toCharArray(), "AMP".toCharArray(), "AMP;".toCharArray(),
            "Aacute".toCharArray(), "Aacute;".toCharArray(),
            "Abreve;".toCharArray(), "Acirc".toCharArray(),
            "Acirc;".toCharArray(), "Acy;".toCharArray(), "Afr;".toCharArray(),
            "Agrave".toCharArray(), "Agrave;".toCharArray(),
            "Alpha;".toCharArray(), "Amacr;".toCharArray(),
            "And;".toCharArray(), "Aogon;".toCharArray(),
            "Aopf;".toCharArray(), "ApplyFunction;".toCharArray(),
            "Aring".toCharArray(), "Aring;".toCharArray(),
            "Ascr;".toCharArray(), "Assign;".toCharArray(),
            "Atilde".toCharArray(), "Atilde;".toCharArray(),
            "Auml".toCharArray(), "Auml;".toCharArray(),
            "Backslash;".toCharArray(), "Barv;".toCharArray(),
            "Barwed;".toCharArray(), "Bcy;".toCharArray(),
            "Because;".toCharArray(), "Bernoullis;".toCharArray(),
            "Beta;".toCharArray(), "Bfr;".toCharArray(), "Bopf;".toCharArray(),
            "Breve;".toCharArray(), "Bscr;".toCharArray(),
            "Bumpeq;".toCharArray(), "CHcy;".toCharArray(),
            "COPY".toCharArray(), "COPY;".toCharArray(),
            "Cacute;".toCharArray(), "Cap;".toCharArray(),
            "CapitalDifferentialD;".toCharArray(), "Cayleys;".toCharArray(),
            "Ccaron;".toCharArray(), "Ccedil".toCharArray(),
            "Ccedil;".toCharArray(), "Ccirc;".toCharArray(),
            "Cconint;".toCharArray(), "Cdot;".toCharArray(),
            "Cedilla;".toCharArray(), "CenterDot;".toCharArray(),
            "Cfr;".toCharArray(), "Chi;".toCharArray(),
            "CircleDot;".toCharArray(), "CircleMinus;".toCharArray(),
            "CirclePlus;".toCharArray(), "CircleTimes;".toCharArray(),
            "ClockwiseContourIntegral;".toCharArray(),
            "CloseCurlyDoubleQuote;".toCharArray(),
            "CloseCurlyQuote;".toCharArray(), "Colon;".toCharArray(),
            "Colone;".toCharArray(), "Congruent;".toCharArray(),
            "Conint;".toCharArray(), "ContourIntegral;".toCharArray(),
            "Copf;".toCharArray(), "Coproduct;".toCharArray(),
            "CounterClockwiseContourIntegral;".toCharArray(),
            "Cross;".toCharArray(), "Cscr;".toCharArray(),
            "Cup;".toCharArray(), "CupCap;".toCharArray(), "DD;".toCharArray(),
            "DDotrahd;".toCharArray(), "DJcy;".toCharArray(),
            "DScy;".toCharArray(), "DZcy;".toCharArray(),
            "Dagger;".toCharArray(), "Darr;".toCharArray(),
            "Dashv;".toCharArray(), "Dcaron;".toCharArray(),
            "Dcy;".toCharArray(), "Del;".toCharArray(), "Delta;".toCharArray(),
            "Dfr;".toCharArray(), "DiacriticalAcute;".toCharArray(),
            "DiacriticalDot;".toCharArray(),
            "DiacriticalDoubleAcute;".toCharArray(),
            "DiacriticalGrave;".toCharArray(),
            "DiacriticalTilde;".toCharArray(), "Diamond;".toCharArray(),
            "DifferentialD;".toCharArray(), "Dopf;".toCharArray(),
            "Dot;".toCharArray(), "DotDot;".toCharArray(),
            "DotEqual;".toCharArray(), "DoubleContourIntegral;".toCharArray(),
            "DoubleDot;".toCharArray(), "DoubleDownArrow;".toCharArray(),
            "DoubleLeftArrow;".toCharArray(),
            "DoubleLeftRightArrow;".toCharArray(),
            "DoubleLeftTee;".toCharArray(),
            "DoubleLongLeftArrow;".toCharArray(),
            "DoubleLongLeftRightArrow;".toCharArray(),
            "DoubleLongRightArrow;".toCharArray(),
            "DoubleRightArrow;".toCharArray(), "DoubleRightTee;".toCharArray(),
            "DoubleUpArrow;".toCharArray(), "DoubleUpDownArrow;".toCharArray(),
            "DoubleVerticalBar;".toCharArray(), "DownArrow;".toCharArray(),
            "DownArrowBar;".toCharArray(), "DownArrowUpArrow;".toCharArray(),
            "DownBreve;".toCharArray(), "DownLeftRightVector;".toCharArray(),
            "DownLeftTeeVector;".toCharArray(),
            "DownLeftVector;".toCharArray(),
            "DownLeftVectorBar;".toCharArray(),
            "DownRightTeeVector;".toCharArray(),
            "DownRightVector;".toCharArray(),
            "DownRightVectorBar;".toCharArray(), "DownTee;".toCharArray(),
            "DownTeeArrow;".toCharArray(), "Downarrow;".toCharArray(),
            "Dscr;".toCharArray(), "Dstrok;".toCharArray(),
            "ENG;".toCharArray(), "ETH".toCharArray(), "ETH;".toCharArray(),
            "Eacute".toCharArray(), "Eacute;".toCharArray(),
            "Ecaron;".toCharArray(), "Ecirc".toCharArray(),
            "Ecirc;".toCharArray(), "Ecy;".toCharArray(),
            "Edot;".toCharArray(), "Efr;".toCharArray(),
            "Egrave".toCharArray(), "Egrave;".toCharArray(),
            "Element;".toCharArray(), "Emacr;".toCharArray(),
            "EmptySmallSquare;".toCharArray(),
            "EmptyVerySmallSquare;".toCharArray(), "Eogon;".toCharArray(),
            "Eopf;".toCharArray(), "Epsilon;".toCharArray(),
            "Equal;".toCharArray(), "EqualTilde;".toCharArray(),
            "Equilibrium;".toCharArray(), "Escr;".toCharArray(),
            "Esim;".toCharArray(), "Eta;".toCharArray(), "Euml".toCharArray(),
            "Euml;".toCharArray(), "Exists;".toCharArray(),
            "ExponentialE;".toCharArray(), "Fcy;".toCharArray(),
            "Ffr;".toCharArray(), "FilledSmallSquare;".toCharArray(),
            "FilledVerySmallSquare;".toCharArray(), "Fopf;".toCharArray(),
            "ForAll;".toCharArray(), "Fouriertrf;".toCharArray(),
            "Fscr;".toCharArray(), "GJcy;".toCharArray(), "GT".toCharArray(),
            "GT;".toCharArray(), "Gamma;".toCharArray(),
            "Gammad;".toCharArray(), "Gbreve;".toCharArray(),
            "Gcedil;".toCharArray(), "Gcirc;".toCharArray(),
            "Gcy;".toCharArray(), "Gdot;".toCharArray(), "Gfr;".toCharArray(),
            "Gg;".toCharArray(), "Gopf;".toCharArray(),
            "GreaterEqual;".toCharArray(), "GreaterEqualLess;".toCharArray(),
            "GreaterFullEqual;".toCharArray(), "GreaterGreater;".toCharArray(),
            "GreaterLess;".toCharArray(), "GreaterSlantEqual;".toCharArray(),
            "GreaterTilde;".toCharArray(), "Gscr;".toCharArray(),
            "Gt;".toCharArray(), "HARDcy;".toCharArray(),
            "Hacek;".toCharArray(), "Hat;".toCharArray(),
            "Hcirc;".toCharArray(), "Hfr;".toCharArray(),
            "HilbertSpace;".toCharArray(), "Hopf;".toCharArray(),
            "HorizontalLine;".toCharArray(), "Hscr;".toCharArray(),
            "Hstrok;".toCharArray(), "HumpDownHump;".toCharArray(),
            "HumpEqual;".toCharArray(), "IEcy;".toCharArray(),
            "IJlig;".toCharArray(), "IOcy;".toCharArray(),
            "Iacute".toCharArray(), "Iacute;".toCharArray(),
            "Icirc".toCharArray(), "Icirc;".toCharArray(),
            "Icy;".toCharArray(), "Idot;".toCharArray(), "Ifr;".toCharArray(),
            "Igrave".toCharArray(), "Igrave;".toCharArray(),
            "Im;".toCharArray(), "Imacr;".toCharArray(),
            "ImaginaryI;".toCharArray(), "Implies;".toCharArray(),
            "Int;".toCharArray(), "Integral;".toCharArray(),
            "Intersection;".toCharArray(), "InvisibleComma;".toCharArray(),
            "InvisibleTimes;".toCharArray(), "Iogon;".toCharArray(),
            "Iopf;".toCharArray(), "Iota;".toCharArray(),
            "Iscr;".toCharArray(), "Itilde;".toCharArray(),
            "Iukcy;".toCharArray(), "Iuml".toCharArray(),
            "Iuml;".toCharArray(), "Jcirc;".toCharArray(),
            "Jcy;".toCharArray(), "Jfr;".toCharArray(), "Jopf;".toCharArray(),
            "Jscr;".toCharArray(), "Jsercy;".toCharArray(),
            "Jukcy;".toCharArray(), "KHcy;".toCharArray(),
            "KJcy;".toCharArray(), "Kappa;".toCharArray(),
            "Kcedil;".toCharArray(), "Kcy;".toCharArray(),
            "Kfr;".toCharArray(), "Kopf;".toCharArray(), "Kscr;".toCharArray(),
            "LJcy;".toCharArray(), "LT".toCharArray(), "LT;".toCharArray(),
            "Lacute;".toCharArray(), "Lambda;".toCharArray(),
            "Lang;".toCharArray(), "Laplacetrf;".toCharArray(),
            "Larr;".toCharArray(), "Lcaron;".toCharArray(),
            "Lcedil;".toCharArray(), "Lcy;".toCharArray(),
            "LeftAngleBracket;".toCharArray(), "LeftArrow;".toCharArray(),
            "LeftArrowBar;".toCharArray(),
            "LeftArrowRightArrow;".toCharArray(), "LeftCeiling;".toCharArray(),
            "LeftDoubleBracket;".toCharArray(),
            "LeftDownTeeVector;".toCharArray(),
            "LeftDownVector;".toCharArray(),
            "LeftDownVectorBar;".toCharArray(), "LeftFloor;".toCharArray(),
            "LeftRightArrow;".toCharArray(), "LeftRightVector;".toCharArray(),
            "LeftTee;".toCharArray(), "LeftTeeArrow;".toCharArray(),
            "LeftTeeVector;".toCharArray(), "LeftTriangle;".toCharArray(),
            "LeftTriangleBar;".toCharArray(),
            "LeftTriangleEqual;".toCharArray(),
            "LeftUpDownVector;".toCharArray(),
            "LeftUpTeeVector;".toCharArray(), "LeftUpVector;".toCharArray(),
            "LeftUpVectorBar;".toCharArray(), "LeftVector;".toCharArray(),
            "LeftVectorBar;".toCharArray(), "Leftarrow;".toCharArray(),
            "Leftrightarrow;".toCharArray(), "LessEqualGreater;".toCharArray(),
            "LessFullEqual;".toCharArray(), "LessGreater;".toCharArray(),
            "LessLess;".toCharArray(), "LessSlantEqual;".toCharArray(),
            "LessTilde;".toCharArray(), "Lfr;".toCharArray(),
            "Ll;".toCharArray(), "Lleftarrow;".toCharArray(),
            "Lmidot;".toCharArray(), "LongLeftArrow;".toCharArray(),
            "LongLeftRightArrow;".toCharArray(),
            "LongRightArrow;".toCharArray(), "Longleftarrow;".toCharArray(),
            "Longleftrightarrow;".toCharArray(),
            "Longrightarrow;".toCharArray(), "Lopf;".toCharArray(),
            "LowerLeftArrow;".toCharArray(), "LowerRightArrow;".toCharArray(),
            "Lscr;".toCharArray(), "Lsh;".toCharArray(),
            "Lstrok;".toCharArray(), "Lt;".toCharArray(), "Map;".toCharArray(),
            "Mcy;".toCharArray(), "MediumSpace;".toCharArray(),
            "Mellintrf;".toCharArray(), "Mfr;".toCharArray(),
            "MinusPlus;".toCharArray(), "Mopf;".toCharArray(),
            "Mscr;".toCharArray(), "Mu;".toCharArray(), "NJcy;".toCharArray(),
            "Nacute;".toCharArray(), "Ncaron;".toCharArray(),
            "Ncedil;".toCharArray(), "Ncy;".toCharArray(),
            "NegativeMediumSpace;".toCharArray(),
            "NegativeThickSpace;".toCharArray(),
            "NegativeThinSpace;".toCharArray(),
            "NegativeVeryThinSpace;".toCharArray(),
            "NestedGreaterGreater;".toCharArray(),
            "NestedLessLess;".toCharArray(), "NewLine;".toCharArray(),
            "Nfr;".toCharArray(), "NoBreak;".toCharArray(),
            "NonBreakingSpace;".toCharArray(), "Nopf;".toCharArray(),
            "Not;".toCharArray(), "NotCongruent;".toCharArray(),
            "NotCupCap;".toCharArray(), "NotDoubleVerticalBar;".toCharArray(),
            "NotElement;".toCharArray(), "NotEqual;".toCharArray(),
            "NotExists;".toCharArray(), "NotGreater;".toCharArray(),
            "NotGreaterEqual;".toCharArray(), "NotGreaterLess;".toCharArray(),
            "NotGreaterTilde;".toCharArray(), "NotLeftTriangle;".toCharArray(),
            "NotLeftTriangleEqual;".toCharArray(), "NotLess;".toCharArray(),
            "NotLessEqual;".toCharArray(), "NotLessGreater;".toCharArray(),
            "NotLessTilde;".toCharArray(), "NotPrecedes;".toCharArray(),
            "NotPrecedesSlantEqual;".toCharArray(),
            "NotReverseElement;".toCharArray(),
            "NotRightTriangle;".toCharArray(),
            "NotRightTriangleEqual;".toCharArray(),
            "NotSquareSubsetEqual;".toCharArray(),
            "NotSquareSupersetEqual;".toCharArray(),
            "NotSubsetEqual;".toCharArray(), "NotSucceeds;".toCharArray(),
            "NotSucceedsSlantEqual;".toCharArray(),
            "NotSupersetEqual;".toCharArray(), "NotTilde;".toCharArray(),
            "NotTildeEqual;".toCharArray(), "NotTildeFullEqual;".toCharArray(),
            "NotTildeTilde;".toCharArray(), "NotVerticalBar;".toCharArray(),
            "Nscr;".toCharArray(), "Ntilde".toCharArray(),
            "Ntilde;".toCharArray(), "Nu;".toCharArray(),
            "OElig;".toCharArray(), "Oacute".toCharArray(),
            "Oacute;".toCharArray(), "Ocirc".toCharArray(),
            "Ocirc;".toCharArray(), "Ocy;".toCharArray(),
            "Odblac;".toCharArray(), "Ofr;".toCharArray(),
            "Ograve".toCharArray(), "Ograve;".toCharArray(),
            "Omacr;".toCharArray(), "Omega;".toCharArray(),
            "Omicron;".toCharArray(), "Oopf;".toCharArray(),
            "OpenCurlyDoubleQuote;".toCharArray(),
            "OpenCurlyQuote;".toCharArray(), "Or;".toCharArray(),
            "Oscr;".toCharArray(), "Oslash".toCharArray(),
            "Oslash;".toCharArray(), "Otilde".toCharArray(),
            "Otilde;".toCharArray(), "Otimes;".toCharArray(),
            "Ouml".toCharArray(), "Ouml;".toCharArray(),
            "OverBar;".toCharArray(), "OverBrace;".toCharArray(),
            "OverBracket;".toCharArray(), "OverParenthesis;".toCharArray(),
            "PartialD;".toCharArray(), "Pcy;".toCharArray(),
            "Pfr;".toCharArray(), "Phi;".toCharArray(), "Pi;".toCharArray(),
            "PlusMinus;".toCharArray(), "Poincareplane;".toCharArray(),
            "Popf;".toCharArray(), "Pr;".toCharArray(),
            "Precedes;".toCharArray(), "PrecedesEqual;".toCharArray(),
            "PrecedesSlantEqual;".toCharArray(),
            "PrecedesTilde;".toCharArray(), "Prime;".toCharArray(),
            "Product;".toCharArray(), "Proportion;".toCharArray(),
            "Proportional;".toCharArray(), "Pscr;".toCharArray(),
            "Psi;".toCharArray(), "QUOT".toCharArray(), "QUOT;".toCharArray(),
            "Qfr;".toCharArray(), "Qopf;".toCharArray(), "Qscr;".toCharArray(),
            "RBarr;".toCharArray(), "REG".toCharArray(), "REG;".toCharArray(),
            "Racute;".toCharArray(), "Rang;".toCharArray(),
            "Rarr;".toCharArray(), "Rarrtl;".toCharArray(),
            "Rcaron;".toCharArray(), "Rcedil;".toCharArray(),
            "Rcy;".toCharArray(), "Re;".toCharArray(),
            "ReverseElement;".toCharArray(),
            "ReverseEquilibrium;".toCharArray(),
            "ReverseUpEquilibrium;".toCharArray(), "Rfr;".toCharArray(),
            "Rho;".toCharArray(), "RightAngleBracket;".toCharArray(),
            "RightArrow;".toCharArray(), "RightArrowBar;".toCharArray(),
            "RightArrowLeftArrow;".toCharArray(),
            "RightCeiling;".toCharArray(), "RightDoubleBracket;".toCharArray(),
            "RightDownTeeVector;".toCharArray(),
            "RightDownVector;".toCharArray(),
            "RightDownVectorBar;".toCharArray(), "RightFloor;".toCharArray(),
            "RightTee;".toCharArray(), "RightTeeArrow;".toCharArray(),
            "RightTeeVector;".toCharArray(), "RightTriangle;".toCharArray(),
            "RightTriangleBar;".toCharArray(),
            "RightTriangleEqual;".toCharArray(),
            "RightUpDownVector;".toCharArray(),
            "RightUpTeeVector;".toCharArray(), "RightUpVector;".toCharArray(),
            "RightUpVectorBar;".toCharArray(), "RightVector;".toCharArray(),
            "RightVectorBar;".toCharArray(), "Rightarrow;".toCharArray(),
            "Ropf;".toCharArray(), "RoundImplies;".toCharArray(),
            "Rrightarrow;".toCharArray(), "Rscr;".toCharArray(),
            "Rsh;".toCharArray(), "RuleDelayed;".toCharArray(),
            "SHCHcy;".toCharArray(), "SHcy;".toCharArray(),
            "SOFTcy;".toCharArray(), "Sacute;".toCharArray(),
            "Sc;".toCharArray(), "Scaron;".toCharArray(),
            "Scedil;".toCharArray(), "Scirc;".toCharArray(),
            "Scy;".toCharArray(), "Sfr;".toCharArray(),
            "ShortDownArrow;".toCharArray(), "ShortLeftArrow;".toCharArray(),
            "ShortRightArrow;".toCharArray(), "ShortUpArrow;".toCharArray(),
            "Sigma;".toCharArray(), "SmallCircle;".toCharArray(),
            "Sopf;".toCharArray(), "Sqrt;".toCharArray(),
            "Square;".toCharArray(), "SquareIntersection;".toCharArray(),
            "SquareSubset;".toCharArray(), "SquareSubsetEqual;".toCharArray(),
            "SquareSuperset;".toCharArray(),
            "SquareSupersetEqual;".toCharArray(), "SquareUnion;".toCharArray(),
            "Sscr;".toCharArray(), "Star;".toCharArray(), "Sub;".toCharArray(),
            "Subset;".toCharArray(), "SubsetEqual;".toCharArray(),
            "Succeeds;".toCharArray(), "SucceedsEqual;".toCharArray(),
            "SucceedsSlantEqual;".toCharArray(),
            "SucceedsTilde;".toCharArray(), "SuchThat;".toCharArray(),
            "Sum;".toCharArray(), "Sup;".toCharArray(),
            "Superset;".toCharArray(), "SupersetEqual;".toCharArray(),
            "Supset;".toCharArray(), "THORN".toCharArray(),
            "THORN;".toCharArray(), "TRADE;".toCharArray(),
            "TSHcy;".toCharArray(), "TScy;".toCharArray(),
            "Tab;".toCharArray(), "Tau;".toCharArray(),
            "Tcaron;".toCharArray(), "Tcedil;".toCharArray(),
            "Tcy;".toCharArray(), "Tfr;".toCharArray(),
            "Therefore;".toCharArray(), "Theta;".toCharArray(),
            "ThinSpace;".toCharArray(), "Tilde;".toCharArray(),
            "TildeEqual;".toCharArray(), "TildeFullEqual;".toCharArray(),
            "TildeTilde;".toCharArray(), "Topf;".toCharArray(),
            "TripleDot;".toCharArray(), "Tscr;".toCharArray(),
            "Tstrok;".toCharArray(), "Uacute".toCharArray(),
            "Uacute;".toCharArray(), "Uarr;".toCharArray(),
            "Uarrocir;".toCharArray(), "Ubrcy;".toCharArray(),
            "Ubreve;".toCharArray(), "Ucirc".toCharArray(),
            "Ucirc;".toCharArray(), "Ucy;".toCharArray(),
            "Udblac;".toCharArray(), "Ufr;".toCharArray(),
            "Ugrave".toCharArray(), "Ugrave;".toCharArray(),
            "Umacr;".toCharArray(), "UnderBar;".toCharArray(),
            "UnderBrace;".toCharArray(), "UnderBracket;".toCharArray(),
            "UnderParenthesis;".toCharArray(), "Union;".toCharArray(),
            "UnionPlus;".toCharArray(), "Uogon;".toCharArray(),
            "Uopf;".toCharArray(), "UpArrow;".toCharArray(),
            "UpArrowBar;".toCharArray(), "UpArrowDownArrow;".toCharArray(),
            "UpDownArrow;".toCharArray(), "UpEquilibrium;".toCharArray(),
            "UpTee;".toCharArray(), "UpTeeArrow;".toCharArray(),
            "Uparrow;".toCharArray(), "Updownarrow;".toCharArray(),
            "UpperLeftArrow;".toCharArray(), "UpperRightArrow;".toCharArray(),
            "Upsi;".toCharArray(), "Upsilon;".toCharArray(),
            "Uring;".toCharArray(), "Uscr;".toCharArray(),
            "Utilde;".toCharArray(), "Uuml".toCharArray(),
            "Uuml;".toCharArray(), "VDash;".toCharArray(),
            "Vbar;".toCharArray(), "Vcy;".toCharArray(),
            "Vdash;".toCharArray(), "Vdashl;".toCharArray(),
            "Vee;".toCharArray(), "Verbar;".toCharArray(),
            "Vert;".toCharArray(), "VerticalBar;".toCharArray(),
            "VerticalLine;".toCharArray(), "VerticalSeparator;".toCharArray(),
            "VerticalTilde;".toCharArray(), "VeryThinSpace;".toCharArray(),
            "Vfr;".toCharArray(), "Vopf;".toCharArray(), "Vscr;".toCharArray(),
            "Vvdash;".toCharArray(), "Wcirc;".toCharArray(),
            "Wedge;".toCharArray(), "Wfr;".toCharArray(),
            "Wopf;".toCharArray(), "Wscr;".toCharArray(), "Xfr;".toCharArray(),
            "Xi;".toCharArray(), "Xopf;".toCharArray(), "Xscr;".toCharArray(),
            "YAcy;".toCharArray(), "YIcy;".toCharArray(),
            "YUcy;".toCharArray(), "Yacute".toCharArray(),
            "Yacute;".toCharArray(), "Ycirc;".toCharArray(),
            "Ycy;".toCharArray(), "Yfr;".toCharArray(), "Yopf;".toCharArray(),
            "Yscr;".toCharArray(), "Yuml;".toCharArray(),
            "ZHcy;".toCharArray(), "Zacute;".toCharArray(),
            "Zcaron;".toCharArray(), "Zcy;".toCharArray(),
            "Zdot;".toCharArray(), "ZeroWidthSpace;".toCharArray(),
            "Zeta;".toCharArray(), "Zfr;".toCharArray(), "Zopf;".toCharArray(),
            "Zscr;".toCharArray(), "aacute".toCharArray(),
            "aacute;".toCharArray(), "abreve;".toCharArray(),
            "ac;".toCharArray(), "acd;".toCharArray(), "acirc".toCharArray(),
            "acirc;".toCharArray(), "acute".toCharArray(),
            "acute;".toCharArray(), "acy;".toCharArray(),
            "aelig".toCharArray(), "aelig;".toCharArray(), "af;".toCharArray(),
            "afr;".toCharArray(), "agrave".toCharArray(),
            "agrave;".toCharArray(), "alefsym;".toCharArray(),
            "aleph;".toCharArray(), "alpha;".toCharArray(),
            "amacr;".toCharArray(), "amalg;".toCharArray(),
            "amp".toCharArray(), "amp;".toCharArray(), "and;".toCharArray(),
            "andand;".toCharArray(), "andd;".toCharArray(),
            "andslope;".toCharArray(), "andv;".toCharArray(),
            "ang;".toCharArray(), "ange;".toCharArray(),
            "angle;".toCharArray(), "angmsd;".toCharArray(),
            "angmsdaa;".toCharArray(), "angmsdab;".toCharArray(),
            "angmsdac;".toCharArray(), "angmsdad;".toCharArray(),
            "angmsdae;".toCharArray(), "angmsdaf;".toCharArray(),
            "angmsdag;".toCharArray(), "angmsdah;".toCharArray(),
            "angrt;".toCharArray(), "angrtvb;".toCharArray(),
            "angrtvbd;".toCharArray(), "angsph;".toCharArray(),
            "angst;".toCharArray(), "angzarr;".toCharArray(),
            "aogon;".toCharArray(), "aopf;".toCharArray(), "ap;".toCharArray(),
            "apE;".toCharArray(), "apacir;".toCharArray(),
            "ape;".toCharArray(), "apid;".toCharArray(), "apos;".toCharArray(),
            "approx;".toCharArray(), "approxeq;".toCharArray(),
            "aring".toCharArray(), "aring;".toCharArray(),
            "ascr;".toCharArray(), "ast;".toCharArray(),
            "asymp;".toCharArray(), "asympeq;".toCharArray(),
            "atilde".toCharArray(), "atilde;".toCharArray(),
            "auml".toCharArray(), "auml;".toCharArray(),
            "awconint;".toCharArray(), "awint;".toCharArray(),
            "bNot;".toCharArray(), "backcong;".toCharArray(),
            "backepsilon;".toCharArray(), "backprime;".toCharArray(),
            "backsim;".toCharArray(), "backsimeq;".toCharArray(),
            "barvee;".toCharArray(), "barwed;".toCharArray(),
            "barwedge;".toCharArray(), "bbrk;".toCharArray(),
            "bbrktbrk;".toCharArray(), "bcong;".toCharArray(),
            "bcy;".toCharArray(), "bdquo;".toCharArray(),
            "becaus;".toCharArray(), "because;".toCharArray(),
            "bemptyv;".toCharArray(), "bepsi;".toCharArray(),
            "bernou;".toCharArray(), "beta;".toCharArray(),
            "beth;".toCharArray(), "between;".toCharArray(),
            "bfr;".toCharArray(), "bigcap;".toCharArray(),
            "bigcirc;".toCharArray(), "bigcup;".toCharArray(),
            "bigodot;".toCharArray(), "bigoplus;".toCharArray(),
            "bigotimes;".toCharArray(), "bigsqcup;".toCharArray(),
            "bigstar;".toCharArray(), "bigtriangledown;".toCharArray(),
            "bigtriangleup;".toCharArray(), "biguplus;".toCharArray(),
            "bigvee;".toCharArray(), "bigwedge;".toCharArray(),
            "bkarow;".toCharArray(), "blacklozenge;".toCharArray(),
            "blacksquare;".toCharArray(), "blacktriangle;".toCharArray(),
            "blacktriangledown;".toCharArray(),
            "blacktriangleleft;".toCharArray(),
            "blacktriangleright;".toCharArray(), "blank;".toCharArray(),
            "blk12;".toCharArray(), "blk14;".toCharArray(),
            "blk34;".toCharArray(), "block;".toCharArray(),
            "bnot;".toCharArray(), "bopf;".toCharArray(), "bot;".toCharArray(),
            "bottom;".toCharArray(), "bowtie;".toCharArray(),
            "boxDL;".toCharArray(), "boxDR;".toCharArray(),
            "boxDl;".toCharArray(), "boxDr;".toCharArray(),
            "boxH;".toCharArray(), "boxHD;".toCharArray(),
            "boxHU;".toCharArray(), "boxHd;".toCharArray(),
            "boxHu;".toCharArray(), "boxUL;".toCharArray(),
            "boxUR;".toCharArray(), "boxUl;".toCharArray(),
            "boxUr;".toCharArray(), "boxV;".toCharArray(),
            "boxVH;".toCharArray(), "boxVL;".toCharArray(),
            "boxVR;".toCharArray(), "boxVh;".toCharArray(),
            "boxVl;".toCharArray(), "boxVr;".toCharArray(),
            "boxbox;".toCharArray(), "boxdL;".toCharArray(),
            "boxdR;".toCharArray(), "boxdl;".toCharArray(),
            "boxdr;".toCharArray(), "boxh;".toCharArray(),
            "boxhD;".toCharArray(), "boxhU;".toCharArray(),
            "boxhd;".toCharArray(), "boxhu;".toCharArray(),
            "boxminus;".toCharArray(), "boxplus;".toCharArray(),
            "boxtimes;".toCharArray(), "boxuL;".toCharArray(),
            "boxuR;".toCharArray(), "boxul;".toCharArray(),
            "boxur;".toCharArray(), "boxv;".toCharArray(),
            "boxvH;".toCharArray(), "boxvL;".toCharArray(),
            "boxvR;".toCharArray(), "boxvh;".toCharArray(),
            "boxvl;".toCharArray(), "boxvr;".toCharArray(),
            "bprime;".toCharArray(), "breve;".toCharArray(),
            "brvbar".toCharArray(), "brvbar;".toCharArray(),
            "bscr;".toCharArray(), "bsemi;".toCharArray(),
            "bsim;".toCharArray(), "bsime;".toCharArray(),
            "bsol;".toCharArray(), "bsolb;".toCharArray(),
            "bull;".toCharArray(), "bullet;".toCharArray(),
            "bump;".toCharArray(), "bumpE;".toCharArray(),
            "bumpe;".toCharArray(), "bumpeq;".toCharArray(),
            "cacute;".toCharArray(), "cap;".toCharArray(),
            "capand;".toCharArray(), "capbrcup;".toCharArray(),
            "capcap;".toCharArray(), "capcup;".toCharArray(),
            "capdot;".toCharArray(), "caret;".toCharArray(),
            "caron;".toCharArray(), "ccaps;".toCharArray(),
            "ccaron;".toCharArray(), "ccedil".toCharArray(),
            "ccedil;".toCharArray(), "ccirc;".toCharArray(),
            "ccups;".toCharArray(), "ccupssm;".toCharArray(),
            "cdot;".toCharArray(), "cedil".toCharArray(),
            "cedil;".toCharArray(), "cemptyv;".toCharArray(),
            "cent".toCharArray(), "cent;".toCharArray(),
            "centerdot;".toCharArray(), "cfr;".toCharArray(),
            "chcy;".toCharArray(), "check;".toCharArray(),
            "checkmark;".toCharArray(), "chi;".toCharArray(),
            "cir;".toCharArray(), "cirE;".toCharArray(), "circ;".toCharArray(),
            "circeq;".toCharArray(), "circlearrowleft;".toCharArray(),
            "circlearrowright;".toCharArray(), "circledR;".toCharArray(),
            "circledS;".toCharArray(), "circledast;".toCharArray(),
            "circledcirc;".toCharArray(), "circleddash;".toCharArray(),
            "cire;".toCharArray(), "cirfnint;".toCharArray(),
            "cirmid;".toCharArray(), "cirscir;".toCharArray(),
            "clubs;".toCharArray(), "clubsuit;".toCharArray(),
            "colon;".toCharArray(), "colone;".toCharArray(),
            "coloneq;".toCharArray(), "comma;".toCharArray(),
            "commat;".toCharArray(), "comp;".toCharArray(),
            "compfn;".toCharArray(), "complement;".toCharArray(),
            "complexes;".toCharArray(), "cong;".toCharArray(),
            "congdot;".toCharArray(), "conint;".toCharArray(),
            "copf;".toCharArray(), "coprod;".toCharArray(),
            "copy".toCharArray(), "copy;".toCharArray(),
            "copysr;".toCharArray(), "crarr;".toCharArray(),
            "cross;".toCharArray(), "cscr;".toCharArray(),
            "csub;".toCharArray(), "csube;".toCharArray(),
            "csup;".toCharArray(), "csupe;".toCharArray(),
            "ctdot;".toCharArray(), "cudarrl;".toCharArray(),
            "cudarrr;".toCharArray(), "cuepr;".toCharArray(),
            "cuesc;".toCharArray(), "cularr;".toCharArray(),
            "cularrp;".toCharArray(), "cup;".toCharArray(),
            "cupbrcap;".toCharArray(), "cupcap;".toCharArray(),
            "cupcup;".toCharArray(), "cupdot;".toCharArray(),
            "cupor;".toCharArray(), "curarr;".toCharArray(),
            "curarrm;".toCharArray(), "curlyeqprec;".toCharArray(),
            "curlyeqsucc;".toCharArray(), "curlyvee;".toCharArray(),
            "curlywedge;".toCharArray(), "curren".toCharArray(),
            "curren;".toCharArray(), "curvearrowleft;".toCharArray(),
            "curvearrowright;".toCharArray(), "cuvee;".toCharArray(),
            "cuwed;".toCharArray(), "cwconint;".toCharArray(),
            "cwint;".toCharArray(), "cylcty;".toCharArray(),
            "dArr;".toCharArray(), "dHar;".toCharArray(),
            "dagger;".toCharArray(), "daleth;".toCharArray(),
            "darr;".toCharArray(), "dash;".toCharArray(),
            "dashv;".toCharArray(), "dbkarow;".toCharArray(),
            "dblac;".toCharArray(), "dcaron;".toCharArray(),
            "dcy;".toCharArray(), "dd;".toCharArray(),
            "ddagger;".toCharArray(), "ddarr;".toCharArray(),
            "ddotseq;".toCharArray(), "deg".toCharArray(),
            "deg;".toCharArray(), "delta;".toCharArray(),
            "demptyv;".toCharArray(), "dfisht;".toCharArray(),
            "dfr;".toCharArray(), "dharl;".toCharArray(),
            "dharr;".toCharArray(), "diam;".toCharArray(),
            "diamond;".toCharArray(), "diamondsuit;".toCharArray(),
            "diams;".toCharArray(), "die;".toCharArray(),
            "digamma;".toCharArray(), "disin;".toCharArray(),
            "div;".toCharArray(), "divide".toCharArray(),
            "divide;".toCharArray(), "divideontimes;".toCharArray(),
            "divonx;".toCharArray(), "djcy;".toCharArray(),
            "dlcorn;".toCharArray(), "dlcrop;".toCharArray(),
            "dollar;".toCharArray(), "dopf;".toCharArray(),
            "dot;".toCharArray(), "doteq;".toCharArray(),
            "doteqdot;".toCharArray(), "dotminus;".toCharArray(),
            "dotplus;".toCharArray(), "dotsquare;".toCharArray(),
            "doublebarwedge;".toCharArray(), "downarrow;".toCharArray(),
            "downdownarrows;".toCharArray(), "downharpoonleft;".toCharArray(),
            "downharpoonright;".toCharArray(), "drbkarow;".toCharArray(),
            "drcorn;".toCharArray(), "drcrop;".toCharArray(),
            "dscr;".toCharArray(), "dscy;".toCharArray(),
            "dsol;".toCharArray(), "dstrok;".toCharArray(),
            "dtdot;".toCharArray(), "dtri;".toCharArray(),
            "dtrif;".toCharArray(), "duarr;".toCharArray(),
            "duhar;".toCharArray(), "dwangle;".toCharArray(),
            "dzcy;".toCharArray(), "dzigrarr;".toCharArray(),
            "eDDot;".toCharArray(), "eDot;".toCharArray(),
            "eacute".toCharArray(), "eacute;".toCharArray(),
            "easter;".toCharArray(), "ecaron;".toCharArray(),
            "ecir;".toCharArray(), "ecirc".toCharArray(),
            "ecirc;".toCharArray(), "ecolon;".toCharArray(),
            "ecy;".toCharArray(), "edot;".toCharArray(), "ee;".toCharArray(),
            "efDot;".toCharArray(), "efr;".toCharArray(), "eg;".toCharArray(),
            "egrave".toCharArray(), "egrave;".toCharArray(),
            "egs;".toCharArray(), "egsdot;".toCharArray(), "el;".toCharArray(),
            "elinters;".toCharArray(), "ell;".toCharArray(),
            "els;".toCharArray(), "elsdot;".toCharArray(),
            "emacr;".toCharArray(), "empty;".toCharArray(),
            "emptyset;".toCharArray(), "emptyv;".toCharArray(),
            "emsp13;".toCharArray(), "emsp14;".toCharArray(),
            "emsp;".toCharArray(), "eng;".toCharArray(), "ensp;".toCharArray(),
            "eogon;".toCharArray(), "eopf;".toCharArray(),
            "epar;".toCharArray(), "eparsl;".toCharArray(),
            "eplus;".toCharArray(), "epsi;".toCharArray(),
            "epsilon;".toCharArray(), "epsiv;".toCharArray(),
            "eqcirc;".toCharArray(), "eqcolon;".toCharArray(),
            "eqsim;".toCharArray(), "eqslantgtr;".toCharArray(),
            "eqslantless;".toCharArray(), "equals;".toCharArray(),
            "equest;".toCharArray(), "equiv;".toCharArray(),
            "equivDD;".toCharArray(), "eqvparsl;".toCharArray(),
            "erDot;".toCharArray(), "erarr;".toCharArray(),
            "escr;".toCharArray(), "esdot;".toCharArray(),
            "esim;".toCharArray(), "eta;".toCharArray(), "eth".toCharArray(),
            "eth;".toCharArray(), "euml".toCharArray(), "euml;".toCharArray(),
            "euro;".toCharArray(), "excl;".toCharArray(),
            "exist;".toCharArray(), "expectation;".toCharArray(),
            "exponentiale;".toCharArray(), "fallingdotseq;".toCharArray(),
            "fcy;".toCharArray(), "female;".toCharArray(),
            "ffilig;".toCharArray(), "fflig;".toCharArray(),
            "ffllig;".toCharArray(), "ffr;".toCharArray(),
            "filig;".toCharArray(), "flat;".toCharArray(),
            "fllig;".toCharArray(), "fltns;".toCharArray(),
            "fnof;".toCharArray(), "fopf;".toCharArray(),
            "forall;".toCharArray(), "fork;".toCharArray(),
            "forkv;".toCharArray(), "fpartint;".toCharArray(),
            "frac12".toCharArray(), "frac12;".toCharArray(),
            "frac13;".toCharArray(), "frac14".toCharArray(),
            "frac14;".toCharArray(), "frac15;".toCharArray(),
            "frac16;".toCharArray(), "frac18;".toCharArray(),
            "frac23;".toCharArray(), "frac25;".toCharArray(),
            "frac34".toCharArray(), "frac34;".toCharArray(),
            "frac35;".toCharArray(), "frac38;".toCharArray(),
            "frac45;".toCharArray(), "frac56;".toCharArray(),
            "frac58;".toCharArray(), "frac78;".toCharArray(),
            "frasl;".toCharArray(), "frown;".toCharArray(),
            "fscr;".toCharArray(), "gE;".toCharArray(), "gEl;".toCharArray(),
            "gacute;".toCharArray(), "gamma;".toCharArray(),
            "gammad;".toCharArray(), "gap;".toCharArray(),
            "gbreve;".toCharArray(), "gcirc;".toCharArray(),
            "gcy;".toCharArray(), "gdot;".toCharArray(), "ge;".toCharArray(),
            "gel;".toCharArray(), "geq;".toCharArray(), "geqq;".toCharArray(),
            "geqslant;".toCharArray(), "ges;".toCharArray(),
            "gescc;".toCharArray(), "gesdot;".toCharArray(),
            "gesdoto;".toCharArray(), "gesdotol;".toCharArray(),
            "gesles;".toCharArray(), "gfr;".toCharArray(), "gg;".toCharArray(),
            "ggg;".toCharArray(), "gimel;".toCharArray(),
            "gjcy;".toCharArray(), "gl;".toCharArray(), "glE;".toCharArray(),
            "gla;".toCharArray(), "glj;".toCharArray(), "gnE;".toCharArray(),
            "gnap;".toCharArray(), "gnapprox;".toCharArray(),
            "gne;".toCharArray(), "gneq;".toCharArray(),
            "gneqq;".toCharArray(), "gnsim;".toCharArray(),
            "gopf;".toCharArray(), "grave;".toCharArray(),
            "gscr;".toCharArray(), "gsim;".toCharArray(),
            "gsime;".toCharArray(), "gsiml;".toCharArray(), "gt".toCharArray(),
            "gt;".toCharArray(), "gtcc;".toCharArray(), "gtcir;".toCharArray(),
            "gtdot;".toCharArray(), "gtlPar;".toCharArray(),
            "gtquest;".toCharArray(), "gtrapprox;".toCharArray(),
            "gtrarr;".toCharArray(), "gtrdot;".toCharArray(),
            "gtreqless;".toCharArray(), "gtreqqless;".toCharArray(),
            "gtrless;".toCharArray(), "gtrsim;".toCharArray(),
            "hArr;".toCharArray(), "hairsp;".toCharArray(),
            "half;".toCharArray(), "hamilt;".toCharArray(),
            "hardcy;".toCharArray(), "harr;".toCharArray(),
            "harrcir;".toCharArray(), "harrw;".toCharArray(),
            "hbar;".toCharArray(), "hcirc;".toCharArray(),
            "hearts;".toCharArray(), "heartsuit;".toCharArray(),
            "hellip;".toCharArray(), "hercon;".toCharArray(),
            "hfr;".toCharArray(), "hksearow;".toCharArray(),
            "hkswarow;".toCharArray(), "hoarr;".toCharArray(),
            "homtht;".toCharArray(), "hookleftarrow;".toCharArray(),
            "hookrightarrow;".toCharArray(), "hopf;".toCharArray(),
            "horbar;".toCharArray(), "hscr;".toCharArray(),
            "hslash;".toCharArray(), "hstrok;".toCharArray(),
            "hybull;".toCharArray(), "hyphen;".toCharArray(),
            "iacute".toCharArray(), "iacute;".toCharArray(),
            "ic;".toCharArray(), "icirc".toCharArray(), "icirc;".toCharArray(),
            "icy;".toCharArray(), "iecy;".toCharArray(), "iexcl".toCharArray(),
            "iexcl;".toCharArray(), "iff;".toCharArray(), "ifr;".toCharArray(),
            "igrave".toCharArray(), "igrave;".toCharArray(),
            "ii;".toCharArray(), "iiiint;".toCharArray(),
            "iiint;".toCharArray(), "iinfin;".toCharArray(),
            "iiota;".toCharArray(), "ijlig;".toCharArray(),
            "imacr;".toCharArray(), "image;".toCharArray(),
            "imagline;".toCharArray(), "imagpart;".toCharArray(),
            "imath;".toCharArray(), "imof;".toCharArray(),
            "imped;".toCharArray(), "in;".toCharArray(),
            "incare;".toCharArray(), "infin;".toCharArray(),
            "infintie;".toCharArray(), "inodot;".toCharArray(),
            "int;".toCharArray(), "intcal;".toCharArray(),
            "integers;".toCharArray(), "intercal;".toCharArray(),
            "intlarhk;".toCharArray(), "intprod;".toCharArray(),
            "iocy;".toCharArray(), "iogon;".toCharArray(),
            "iopf;".toCharArray(), "iota;".toCharArray(),
            "iprod;".toCharArray(), "iquest".toCharArray(),
            "iquest;".toCharArray(), "iscr;".toCharArray(),
            "isin;".toCharArray(), "isinE;".toCharArray(),
            "isindot;".toCharArray(), "isins;".toCharArray(),
            "isinsv;".toCharArray(), "isinv;".toCharArray(),
            "it;".toCharArray(), "itilde;".toCharArray(),
            "iukcy;".toCharArray(), "iuml".toCharArray(),
            "iuml;".toCharArray(), "jcirc;".toCharArray(),
            "jcy;".toCharArray(), "jfr;".toCharArray(), "jmath;".toCharArray(),
            "jopf;".toCharArray(), "jscr;".toCharArray(),
            "jsercy;".toCharArray(), "jukcy;".toCharArray(),
            "kappa;".toCharArray(), "kappav;".toCharArray(),
            "kcedil;".toCharArray(), "kcy;".toCharArray(),
            "kfr;".toCharArray(), "kgreen;".toCharArray(),
            "khcy;".toCharArray(), "kjcy;".toCharArray(),
            "kopf;".toCharArray(), "kscr;".toCharArray(),
            "lAarr;".toCharArray(), "lArr;".toCharArray(),
            "lAtail;".toCharArray(), "lBarr;".toCharArray(),
            "lE;".toCharArray(), "lEg;".toCharArray(), "lHar;".toCharArray(),
            "lacute;".toCharArray(), "laemptyv;".toCharArray(),
            "lagran;".toCharArray(), "lambda;".toCharArray(),
            "lang;".toCharArray(), "langd;".toCharArray(),
            "langle;".toCharArray(), "lap;".toCharArray(),
            "laquo".toCharArray(), "laquo;".toCharArray(),
            "larr;".toCharArray(), "larrb;".toCharArray(),
            "larrbfs;".toCharArray(), "larrfs;".toCharArray(),
            "larrhk;".toCharArray(), "larrlp;".toCharArray(),
            "larrpl;".toCharArray(), "larrsim;".toCharArray(),
            "larrtl;".toCharArray(), "lat;".toCharArray(),
            "latail;".toCharArray(), "late;".toCharArray(),
            "lbarr;".toCharArray(), "lbbrk;".toCharArray(),
            "lbrace;".toCharArray(), "lbrack;".toCharArray(),
            "lbrke;".toCharArray(), "lbrksld;".toCharArray(),
            "lbrkslu;".toCharArray(), "lcaron;".toCharArray(),
            "lcedil;".toCharArray(), "lceil;".toCharArray(),
            "lcub;".toCharArray(), "lcy;".toCharArray(), "ldca;".toCharArray(),
            "ldquo;".toCharArray(), "ldquor;".toCharArray(),
            "ldrdhar;".toCharArray(), "ldrushar;".toCharArray(),
            "ldsh;".toCharArray(), "le;".toCharArray(),
            "leftarrow;".toCharArray(), "leftarrowtail;".toCharArray(),
            "leftharpoondown;".toCharArray(), "leftharpoonup;".toCharArray(),
            "leftleftarrows;".toCharArray(), "leftrightarrow;".toCharArray(),
            "leftrightarrows;".toCharArray(),
            "leftrightharpoons;".toCharArray(),
            "leftrightsquigarrow;".toCharArray(),
            "leftthreetimes;".toCharArray(), "leg;".toCharArray(),
            "leq;".toCharArray(), "leqq;".toCharArray(),
            "leqslant;".toCharArray(), "les;".toCharArray(),
            "lescc;".toCharArray(), "lesdot;".toCharArray(),
            "lesdoto;".toCharArray(), "lesdotor;".toCharArray(),
            "lesges;".toCharArray(), "lessapprox;".toCharArray(),
            "lessdot;".toCharArray(), "lesseqgtr;".toCharArray(),
            "lesseqqgtr;".toCharArray(), "lessgtr;".toCharArray(),
            "lesssim;".toCharArray(), "lfisht;".toCharArray(),
            "lfloor;".toCharArray(), "lfr;".toCharArray(), "lg;".toCharArray(),
            "lgE;".toCharArray(), "lhard;".toCharArray(),
            "lharu;".toCharArray(), "lharul;".toCharArray(),
            "lhblk;".toCharArray(), "ljcy;".toCharArray(), "ll;".toCharArray(),
            "llarr;".toCharArray(), "llcorner;".toCharArray(),
            "llhard;".toCharArray(), "lltri;".toCharArray(),
            "lmidot;".toCharArray(), "lmoust;".toCharArray(),
            "lmoustache;".toCharArray(), "lnE;".toCharArray(),
            "lnap;".toCharArray(), "lnapprox;".toCharArray(),
            "lne;".toCharArray(), "lneq;".toCharArray(),
            "lneqq;".toCharArray(), "lnsim;".toCharArray(),
            "loang;".toCharArray(), "loarr;".toCharArray(),
            "lobrk;".toCharArray(), "longleftarrow;".toCharArray(),
            "longleftrightarrow;".toCharArray(), "longmapsto;".toCharArray(),
            "longrightarrow;".toCharArray(), "looparrowleft;".toCharArray(),
            "looparrowright;".toCharArray(), "lopar;".toCharArray(),
            "lopf;".toCharArray(), "loplus;".toCharArray(),
            "lotimes;".toCharArray(), "lowast;".toCharArray(),
            "lowbar;".toCharArray(), "loz;".toCharArray(),
            "lozenge;".toCharArray(), "lozf;".toCharArray(),
            "lpar;".toCharArray(), "lparlt;".toCharArray(),
            "lrarr;".toCharArray(), "lrcorner;".toCharArray(),
            "lrhar;".toCharArray(), "lrhard;".toCharArray(),
            "lrm;".toCharArray(), "lrtri;".toCharArray(),
            "lsaquo;".toCharArray(), "lscr;".toCharArray(),
            "lsh;".toCharArray(), "lsim;".toCharArray(),
            "lsime;".toCharArray(), "lsimg;".toCharArray(),
            "lsqb;".toCharArray(), "lsquo;".toCharArray(),
            "lsquor;".toCharArray(), "lstrok;".toCharArray(),
            "lt".toCharArray(), "lt;".toCharArray(), "ltcc;".toCharArray(),
            "ltcir;".toCharArray(), "ltdot;".toCharArray(),
            "lthree;".toCharArray(), "ltimes;".toCharArray(),
            "ltlarr;".toCharArray(), "ltquest;".toCharArray(),
            "ltrPar;".toCharArray(), "ltri;".toCharArray(),
            "ltrie;".toCharArray(), "ltrif;".toCharArray(),
            "lurdshar;".toCharArray(), "luruhar;".toCharArray(),
            "mDDot;".toCharArray(), "macr".toCharArray(),
            "macr;".toCharArray(), "male;".toCharArray(),
            "malt;".toCharArray(), "maltese;".toCharArray(),
            "map;".toCharArray(), "mapsto;".toCharArray(),
            "mapstodown;".toCharArray(), "mapstoleft;".toCharArray(),
            "mapstoup;".toCharArray(), "marker;".toCharArray(),
            "mcomma;".toCharArray(), "mcy;".toCharArray(),
            "mdash;".toCharArray(), "measuredangle;".toCharArray(),
            "mfr;".toCharArray(), "mho;".toCharArray(), "micro".toCharArray(),
            "micro;".toCharArray(), "mid;".toCharArray(),
            "midast;".toCharArray(), "midcir;".toCharArray(),
            "middot".toCharArray(), "middot;".toCharArray(),
            "minus;".toCharArray(), "minusb;".toCharArray(),
            "minusd;".toCharArray(), "minusdu;".toCharArray(),
            "mlcp;".toCharArray(), "mldr;".toCharArray(),
            "mnplus;".toCharArray(), "models;".toCharArray(),
            "mopf;".toCharArray(), "mp;".toCharArray(), "mscr;".toCharArray(),
            "mstpos;".toCharArray(), "mu;".toCharArray(),
            "multimap;".toCharArray(), "mumap;".toCharArray(),
            "nLeftarrow;".toCharArray(), "nLeftrightarrow;".toCharArray(),
            "nRightarrow;".toCharArray(), "nVDash;".toCharArray(),
            "nVdash;".toCharArray(), "nabla;".toCharArray(),
            "nacute;".toCharArray(), "nap;".toCharArray(),
            "napos;".toCharArray(), "napprox;".toCharArray(),
            "natur;".toCharArray(), "natural;".toCharArray(),
            "naturals;".toCharArray(), "nbsp".toCharArray(),
            "nbsp;".toCharArray(), "ncap;".toCharArray(),
            "ncaron;".toCharArray(), "ncedil;".toCharArray(),
            "ncong;".toCharArray(), "ncup;".toCharArray(),
            "ncy;".toCharArray(), "ndash;".toCharArray(), "ne;".toCharArray(),
            "neArr;".toCharArray(), "nearhk;".toCharArray(),
            "nearr;".toCharArray(), "nearrow;".toCharArray(),
            "nequiv;".toCharArray(), "nesear;".toCharArray(),
            "nexist;".toCharArray(), "nexists;".toCharArray(),
            "nfr;".toCharArray(), "nge;".toCharArray(), "ngeq;".toCharArray(),
            "ngsim;".toCharArray(), "ngt;".toCharArray(),
            "ngtr;".toCharArray(), "nhArr;".toCharArray(),
            "nharr;".toCharArray(), "nhpar;".toCharArray(),
            "ni;".toCharArray(), "nis;".toCharArray(), "nisd;".toCharArray(),
            "niv;".toCharArray(), "njcy;".toCharArray(),
            "nlArr;".toCharArray(), "nlarr;".toCharArray(),
            "nldr;".toCharArray(), "nle;".toCharArray(),
            "nleftarrow;".toCharArray(), "nleftrightarrow;".toCharArray(),
            "nleq;".toCharArray(), "nless;".toCharArray(),
            "nlsim;".toCharArray(), "nlt;".toCharArray(),
            "nltri;".toCharArray(), "nltrie;".toCharArray(),
            "nmid;".toCharArray(), "nopf;".toCharArray(), "not".toCharArray(),
            "not;".toCharArray(), "notin;".toCharArray(),
            "notinva;".toCharArray(), "notinvb;".toCharArray(),
            "notinvc;".toCharArray(), "notni;".toCharArray(),
            "notniva;".toCharArray(), "notnivb;".toCharArray(),
            "notnivc;".toCharArray(), "npar;".toCharArray(),
            "nparallel;".toCharArray(), "npolint;".toCharArray(),
            "npr;".toCharArray(), "nprcue;".toCharArray(),
            "nprec;".toCharArray(), "nrArr;".toCharArray(),
            "nrarr;".toCharArray(), "nrightarrow;".toCharArray(),
            "nrtri;".toCharArray(), "nrtrie;".toCharArray(),
            "nsc;".toCharArray(), "nsccue;".toCharArray(),
            "nscr;".toCharArray(), "nshortmid;".toCharArray(),
            "nshortparallel;".toCharArray(), "nsim;".toCharArray(),
            "nsime;".toCharArray(), "nsimeq;".toCharArray(),
            "nsmid;".toCharArray(), "nspar;".toCharArray(),
            "nsqsube;".toCharArray(), "nsqsupe;".toCharArray(),
            "nsub;".toCharArray(), "nsube;".toCharArray(),
            "nsubseteq;".toCharArray(), "nsucc;".toCharArray(),
            "nsup;".toCharArray(), "nsupe;".toCharArray(),
            "nsupseteq;".toCharArray(), "ntgl;".toCharArray(),
            "ntilde".toCharArray(), "ntilde;".toCharArray(),
            "ntlg;".toCharArray(), "ntriangleleft;".toCharArray(),
            "ntrianglelefteq;".toCharArray(), "ntriangleright;".toCharArray(),
            "ntrianglerighteq;".toCharArray(), "nu;".toCharArray(),
            "num;".toCharArray(), "numero;".toCharArray(),
            "numsp;".toCharArray(), "nvDash;".toCharArray(),
            "nvHarr;".toCharArray(), "nvdash;".toCharArray(),
            "nvinfin;".toCharArray(), "nvlArr;".toCharArray(),
            "nvrArr;".toCharArray(), "nwArr;".toCharArray(),
            "nwarhk;".toCharArray(), "nwarr;".toCharArray(),
            "nwarrow;".toCharArray(), "nwnear;".toCharArray(),
            "oS;".toCharArray(), "oacute".toCharArray(),
            "oacute;".toCharArray(), "oast;".toCharArray(),
            "ocir;".toCharArray(), "ocirc".toCharArray(),
            "ocirc;".toCharArray(), "ocy;".toCharArray(),
            "odash;".toCharArray(), "odblac;".toCharArray(),
            "odiv;".toCharArray(), "odot;".toCharArray(),
            "odsold;".toCharArray(), "oelig;".toCharArray(),
            "ofcir;".toCharArray(), "ofr;".toCharArray(),
            "ogon;".toCharArray(), "ograve".toCharArray(),
            "ograve;".toCharArray(), "ogt;".toCharArray(),
            "ohbar;".toCharArray(), "ohm;".toCharArray(),
            "oint;".toCharArray(), "olarr;".toCharArray(),
            "olcir;".toCharArray(), "olcross;".toCharArray(),
            "oline;".toCharArray(), "olt;".toCharArray(),
            "omacr;".toCharArray(), "omega;".toCharArray(),
            "omicron;".toCharArray(), "omid;".toCharArray(),
            "ominus;".toCharArray(), "oopf;".toCharArray(),
            "opar;".toCharArray(), "operp;".toCharArray(),
            "oplus;".toCharArray(), "or;".toCharArray(),
            "orarr;".toCharArray(), "ord;".toCharArray(),
            "order;".toCharArray(), "orderof;".toCharArray(),
            "ordf".toCharArray(), "ordf;".toCharArray(), "ordm".toCharArray(),
            "ordm;".toCharArray(), "origof;".toCharArray(),
            "oror;".toCharArray(), "orslope;".toCharArray(),
            "orv;".toCharArray(), "oscr;".toCharArray(),
            "oslash".toCharArray(), "oslash;".toCharArray(),
            "osol;".toCharArray(), "otilde".toCharArray(),
            "otilde;".toCharArray(), "otimes;".toCharArray(),
            "otimesas;".toCharArray(), "ouml".toCharArray(),
            "ouml;".toCharArray(), "ovbar;".toCharArray(),
            "par;".toCharArray(), "para".toCharArray(), "para;".toCharArray(),
            "parallel;".toCharArray(), "parsim;".toCharArray(),
            "parsl;".toCharArray(), "part;".toCharArray(),
            "pcy;".toCharArray(), "percnt;".toCharArray(),
            "period;".toCharArray(), "permil;".toCharArray(),
            "perp;".toCharArray(), "pertenk;".toCharArray(),
            "pfr;".toCharArray(), "phi;".toCharArray(), "phiv;".toCharArray(),
            "phmmat;".toCharArray(), "phone;".toCharArray(),
            "pi;".toCharArray(), "pitchfork;".toCharArray(),
            "piv;".toCharArray(), "planck;".toCharArray(),
            "planckh;".toCharArray(), "plankv;".toCharArray(),
            "plus;".toCharArray(), "plusacir;".toCharArray(),
            "plusb;".toCharArray(), "pluscir;".toCharArray(),
            "plusdo;".toCharArray(), "plusdu;".toCharArray(),
            "pluse;".toCharArray(), "plusmn".toCharArray(),
            "plusmn;".toCharArray(), "plussim;".toCharArray(),
            "plustwo;".toCharArray(), "pm;".toCharArray(),
            "pointint;".toCharArray(), "popf;".toCharArray(),
            "pound".toCharArray(), "pound;".toCharArray(), "pr;".toCharArray(),
            "prE;".toCharArray(), "prap;".toCharArray(),
            "prcue;".toCharArray(), "pre;".toCharArray(),
            "prec;".toCharArray(), "precapprox;".toCharArray(),
            "preccurlyeq;".toCharArray(), "preceq;".toCharArray(),
            "precnapprox;".toCharArray(), "precneqq;".toCharArray(),
            "precnsim;".toCharArray(), "precsim;".toCharArray(),
            "prime;".toCharArray(), "primes;".toCharArray(),
            "prnE;".toCharArray(), "prnap;".toCharArray(),
            "prnsim;".toCharArray(), "prod;".toCharArray(),
            "profalar;".toCharArray(), "profline;".toCharArray(),
            "profsurf;".toCharArray(), "prop;".toCharArray(),
            "propto;".toCharArray(), "prsim;".toCharArray(),
            "prurel;".toCharArray(), "pscr;".toCharArray(),
            "psi;".toCharArray(), "puncsp;".toCharArray(),
            "qfr;".toCharArray(), "qint;".toCharArray(), "qopf;".toCharArray(),
            "qprime;".toCharArray(), "qscr;".toCharArray(),
            "quaternions;".toCharArray(), "quatint;".toCharArray(),
            "quest;".toCharArray(), "questeq;".toCharArray(),
            "quot".toCharArray(), "quot;".toCharArray(),
            "rAarr;".toCharArray(), "rArr;".toCharArray(),
            "rAtail;".toCharArray(), "rBarr;".toCharArray(),
            "rHar;".toCharArray(), "race;".toCharArray(),
            "racute;".toCharArray(), "radic;".toCharArray(),
            "raemptyv;".toCharArray(), "rang;".toCharArray(),
            "rangd;".toCharArray(), "range;".toCharArray(),
            "rangle;".toCharArray(), "raquo".toCharArray(),
            "raquo;".toCharArray(), "rarr;".toCharArray(),
            "rarrap;".toCharArray(), "rarrb;".toCharArray(),
            "rarrbfs;".toCharArray(), "rarrc;".toCharArray(),
            "rarrfs;".toCharArray(), "rarrhk;".toCharArray(),
            "rarrlp;".toCharArray(), "rarrpl;".toCharArray(),
            "rarrsim;".toCharArray(), "rarrtl;".toCharArray(),
            "rarrw;".toCharArray(), "ratail;".toCharArray(),
            "ratio;".toCharArray(), "rationals;".toCharArray(),
            "rbarr;".toCharArray(), "rbbrk;".toCharArray(),
            "rbrace;".toCharArray(), "rbrack;".toCharArray(),
            "rbrke;".toCharArray(), "rbrksld;".toCharArray(),
            "rbrkslu;".toCharArray(), "rcaron;".toCharArray(),
            "rcedil;".toCharArray(), "rceil;".toCharArray(),
            "rcub;".toCharArray(), "rcy;".toCharArray(), "rdca;".toCharArray(),
            "rdldhar;".toCharArray(), "rdquo;".toCharArray(),
            "rdquor;".toCharArray(), "rdsh;".toCharArray(),
            "real;".toCharArray(), "realine;".toCharArray(),
            "realpart;".toCharArray(), "reals;".toCharArray(),
            "rect;".toCharArray(), "reg".toCharArray(), "reg;".toCharArray(),
            "rfisht;".toCharArray(), "rfloor;".toCharArray(),
            "rfr;".toCharArray(), "rhard;".toCharArray(),
            "rharu;".toCharArray(), "rharul;".toCharArray(),
            "rho;".toCharArray(), "rhov;".toCharArray(),
            "rightarrow;".toCharArray(), "rightarrowtail;".toCharArray(),
            "rightharpoondown;".toCharArray(), "rightharpoonup;".toCharArray(),
            "rightleftarrows;".toCharArray(),
            "rightleftharpoons;".toCharArray(),
            "rightrightarrows;".toCharArray(),
            "rightsquigarrow;".toCharArray(), "rightthreetimes;".toCharArray(),
            "ring;".toCharArray(), "risingdotseq;".toCharArray(),
            "rlarr;".toCharArray(), "rlhar;".toCharArray(),
            "rlm;".toCharArray(), "rmoust;".toCharArray(),
            "rmoustache;".toCharArray(), "rnmid;".toCharArray(),
            "roang;".toCharArray(), "roarr;".toCharArray(),
            "robrk;".toCharArray(), "ropar;".toCharArray(),
            "ropf;".toCharArray(), "roplus;".toCharArray(),
            "rotimes;".toCharArray(), "rpar;".toCharArray(),
            "rpargt;".toCharArray(), "rppolint;".toCharArray(),
            "rrarr;".toCharArray(), "rsaquo;".toCharArray(),
            "rscr;".toCharArray(), "rsh;".toCharArray(), "rsqb;".toCharArray(),
            "rsquo;".toCharArray(), "rsquor;".toCharArray(),
            "rthree;".toCharArray(), "rtimes;".toCharArray(),
            "rtri;".toCharArray(), "rtrie;".toCharArray(),
            "rtrif;".toCharArray(), "rtriltri;".toCharArray(),
            "ruluhar;".toCharArray(), "rx;".toCharArray(),
            "sacute;".toCharArray(), "sbquo;".toCharArray(),
            "sc;".toCharArray(), "scE;".toCharArray(), "scap;".toCharArray(),
            "scaron;".toCharArray(), "sccue;".toCharArray(),
            "sce;".toCharArray(), "scedil;".toCharArray(),
            "scirc;".toCharArray(), "scnE;".toCharArray(),
            "scnap;".toCharArray(), "scnsim;".toCharArray(),
            "scpolint;".toCharArray(), "scsim;".toCharArray(),
            "scy;".toCharArray(), "sdot;".toCharArray(),
            "sdotb;".toCharArray(), "sdote;".toCharArray(),
            "seArr;".toCharArray(), "searhk;".toCharArray(),
            "searr;".toCharArray(), "searrow;".toCharArray(),
            "sect".toCharArray(), "sect;".toCharArray(), "semi;".toCharArray(),
            "seswar;".toCharArray(), "setminus;".toCharArray(),
            "setmn;".toCharArray(), "sext;".toCharArray(),
            "sfr;".toCharArray(), "sfrown;".toCharArray(),
            "sharp;".toCharArray(), "shchcy;".toCharArray(),
            "shcy;".toCharArray(), "shortmid;".toCharArray(),
            "shortparallel;".toCharArray(), "shy".toCharArray(),
            "shy;".toCharArray(), "sigma;".toCharArray(),
            "sigmaf;".toCharArray(), "sigmav;".toCharArray(),
            "sim;".toCharArray(), "simdot;".toCharArray(),
            "sime;".toCharArray(), "simeq;".toCharArray(),
            "simg;".toCharArray(), "simgE;".toCharArray(),
            "siml;".toCharArray(), "simlE;".toCharArray(),
            "simne;".toCharArray(), "simplus;".toCharArray(),
            "simrarr;".toCharArray(), "slarr;".toCharArray(),
            "smallsetminus;".toCharArray(), "smashp;".toCharArray(),
            "smeparsl;".toCharArray(), "smid;".toCharArray(),
            "smile;".toCharArray(), "smt;".toCharArray(),
            "smte;".toCharArray(), "softcy;".toCharArray(),
            "sol;".toCharArray(), "solb;".toCharArray(),
            "solbar;".toCharArray(), "sopf;".toCharArray(),
            "spades;".toCharArray(), "spadesuit;".toCharArray(),
            "spar;".toCharArray(), "sqcap;".toCharArray(),
            "sqcup;".toCharArray(), "sqsub;".toCharArray(),
            "sqsube;".toCharArray(), "sqsubset;".toCharArray(),
            "sqsubseteq;".toCharArray(), "sqsup;".toCharArray(),
            "sqsupe;".toCharArray(), "sqsupset;".toCharArray(),
            "sqsupseteq;".toCharArray(), "squ;".toCharArray(),
            "square;".toCharArray(), "squarf;".toCharArray(),
            "squf;".toCharArray(), "srarr;".toCharArray(),
            "sscr;".toCharArray(), "ssetmn;".toCharArray(),
            "ssmile;".toCharArray(), "sstarf;".toCharArray(),
            "star;".toCharArray(), "starf;".toCharArray(),
            "straightepsilon;".toCharArray(), "straightphi;".toCharArray(),
            "strns;".toCharArray(), "sub;".toCharArray(),
            "subE;".toCharArray(), "subdot;".toCharArray(),
            "sube;".toCharArray(), "subedot;".toCharArray(),
            "submult;".toCharArray(), "subnE;".toCharArray(),
            "subne;".toCharArray(), "subplus;".toCharArray(),
            "subrarr;".toCharArray(), "subset;".toCharArray(),
            "subseteq;".toCharArray(), "subseteqq;".toCharArray(),
            "subsetneq;".toCharArray(), "subsetneqq;".toCharArray(),
            "subsim;".toCharArray(), "subsub;".toCharArray(),
            "subsup;".toCharArray(), "succ;".toCharArray(),
            "succapprox;".toCharArray(), "succcurlyeq;".toCharArray(),
            "succeq;".toCharArray(), "succnapprox;".toCharArray(),
            "succneqq;".toCharArray(), "succnsim;".toCharArray(),
            "succsim;".toCharArray(), "sum;".toCharArray(),
            "sung;".toCharArray(), "sup1".toCharArray(), "sup1;".toCharArray(),
            "sup2".toCharArray(), "sup2;".toCharArray(), "sup3".toCharArray(),
            "sup3;".toCharArray(), "sup;".toCharArray(), "supE;".toCharArray(),
            "supdot;".toCharArray(), "supdsub;".toCharArray(),
            "supe;".toCharArray(), "supedot;".toCharArray(),
            "suphsub;".toCharArray(), "suplarr;".toCharArray(),
            "supmult;".toCharArray(), "supnE;".toCharArray(),
            "supne;".toCharArray(), "supplus;".toCharArray(),
            "supset;".toCharArray(), "supseteq;".toCharArray(),
            "supseteqq;".toCharArray(), "supsetneq;".toCharArray(),
            "supsetneqq;".toCharArray(), "supsim;".toCharArray(),
            "supsub;".toCharArray(), "supsup;".toCharArray(),
            "swArr;".toCharArray(), "swarhk;".toCharArray(),
            "swarr;".toCharArray(), "swarrow;".toCharArray(),
            "swnwar;".toCharArray(), "szlig".toCharArray(),
            "szlig;".toCharArray(), "target;".toCharArray(),
            "tau;".toCharArray(), "tbrk;".toCharArray(),
            "tcaron;".toCharArray(), "tcedil;".toCharArray(),
            "tcy;".toCharArray(), "tdot;".toCharArray(),
            "telrec;".toCharArray(), "tfr;".toCharArray(),
            "there4;".toCharArray(), "therefore;".toCharArray(),
            "theta;".toCharArray(), "thetasym;".toCharArray(),
            "thetav;".toCharArray(), "thickapprox;".toCharArray(),
            "thicksim;".toCharArray(), "thinsp;".toCharArray(),
            "thkap;".toCharArray(), "thksim;".toCharArray(),
            "thorn".toCharArray(), "thorn;".toCharArray(),
            "tilde;".toCharArray(), "times".toCharArray(),
            "times;".toCharArray(), "timesb;".toCharArray(),
            "timesbar;".toCharArray(), "timesd;".toCharArray(),
            "tint;".toCharArray(), "toea;".toCharArray(), "top;".toCharArray(),
            "topbot;".toCharArray(), "topcir;".toCharArray(),
            "topf;".toCharArray(), "topfork;".toCharArray(),
            "tosa;".toCharArray(), "tprime;".toCharArray(),
            "trade;".toCharArray(), "triangle;".toCharArray(),
            "triangledown;".toCharArray(), "triangleleft;".toCharArray(),
            "trianglelefteq;".toCharArray(), "triangleq;".toCharArray(),
            "triangleright;".toCharArray(), "trianglerighteq;".toCharArray(),
            "tridot;".toCharArray(), "trie;".toCharArray(),
            "triminus;".toCharArray(), "triplus;".toCharArray(),
            "trisb;".toCharArray(), "tritime;".toCharArray(),
            "trpezium;".toCharArray(), "tscr;".toCharArray(),
            "tscy;".toCharArray(), "tshcy;".toCharArray(),
            "tstrok;".toCharArray(), "twixt;".toCharArray(),
            "twoheadleftarrow;".toCharArray(),
            "twoheadrightarrow;".toCharArray(), "uArr;".toCharArray(),
            "uHar;".toCharArray(), "uacute".toCharArray(),
            "uacute;".toCharArray(), "uarr;".toCharArray(),
            "ubrcy;".toCharArray(), "ubreve;".toCharArray(),
            "ucirc".toCharArray(), "ucirc;".toCharArray(),
            "ucy;".toCharArray(), "udarr;".toCharArray(),
            "udblac;".toCharArray(), "udhar;".toCharArray(),
            "ufisht;".toCharArray(), "ufr;".toCharArray(),
            "ugrave".toCharArray(), "ugrave;".toCharArray(),
            "uharl;".toCharArray(), "uharr;".toCharArray(),
            "uhblk;".toCharArray(), "ulcorn;".toCharArray(),
            "ulcorner;".toCharArray(), "ulcrop;".toCharArray(),
            "ultri;".toCharArray(), "umacr;".toCharArray(),
            "uml".toCharArray(), "uml;".toCharArray(), "uogon;".toCharArray(),
            "uopf;".toCharArray(), "uparrow;".toCharArray(),
            "updownarrow;".toCharArray(), "upharpoonleft;".toCharArray(),
            "upharpoonright;".toCharArray(), "uplus;".toCharArray(),
            "upsi;".toCharArray(), "upsih;".toCharArray(),
            "upsilon;".toCharArray(), "upuparrows;".toCharArray(),
            "urcorn;".toCharArray(), "urcorner;".toCharArray(),
            "urcrop;".toCharArray(), "uring;".toCharArray(),
            "urtri;".toCharArray(), "uscr;".toCharArray(),
            "utdot;".toCharArray(), "utilde;".toCharArray(),
            "utri;".toCharArray(), "utrif;".toCharArray(),
            "uuarr;".toCharArray(), "uuml".toCharArray(),
            "uuml;".toCharArray(), "uwangle;".toCharArray(),
            "vArr;".toCharArray(), "vBar;".toCharArray(),
            "vBarv;".toCharArray(), "vDash;".toCharArray(),
            "vangrt;".toCharArray(), "varepsilon;".toCharArray(),
            "varkappa;".toCharArray(), "varnothing;".toCharArray(),
            "varphi;".toCharArray(), "varpi;".toCharArray(),
            "varpropto;".toCharArray(), "varr;".toCharArray(),
            "varrho;".toCharArray(), "varsigma;".toCharArray(),
            "vartheta;".toCharArray(), "vartriangleleft;".toCharArray(),
            "vartriangleright;".toCharArray(), "vcy;".toCharArray(),
            "vdash;".toCharArray(), "vee;".toCharArray(),
            "veebar;".toCharArray(), "veeeq;".toCharArray(),
            "vellip;".toCharArray(), "verbar;".toCharArray(),
            "vert;".toCharArray(), "vfr;".toCharArray(),
            "vltri;".toCharArray(), "vopf;".toCharArray(),
            "vprop;".toCharArray(), "vrtri;".toCharArray(),
            "vscr;".toCharArray(), "vzigzag;".toCharArray(),
            "wcirc;".toCharArray(), "wedbar;".toCharArray(),
            "wedge;".toCharArray(), "wedgeq;".toCharArray(),
            "weierp;".toCharArray(), "wfr;".toCharArray(),
            "wopf;".toCharArray(), "wp;".toCharArray(), "wr;".toCharArray(),
            "wreath;".toCharArray(), "wscr;".toCharArray(),
            "xcap;".toCharArray(), "xcirc;".toCharArray(),
            "xcup;".toCharArray(), "xdtri;".toCharArray(),
            "xfr;".toCharArray(), "xhArr;".toCharArray(),
            "xharr;".toCharArray(), "xi;".toCharArray(),
            "xlArr;".toCharArray(), "xlarr;".toCharArray(),
            "xmap;".toCharArray(), "xnis;".toCharArray(),
            "xodot;".toCharArray(), "xopf;".toCharArray(),
            "xoplus;".toCharArray(), "xotime;".toCharArray(),
            "xrArr;".toCharArray(), "xrarr;".toCharArray(),
            "xscr;".toCharArray(), "xsqcup;".toCharArray(),
            "xuplus;".toCharArray(), "xutri;".toCharArray(),
            "xvee;".toCharArray(), "xwedge;".toCharArray(),
            "yacute".toCharArray(), "yacute;".toCharArray(),
            "yacy;".toCharArray(), "ycirc;".toCharArray(),
            "ycy;".toCharArray(), "yen".toCharArray(), "yen;".toCharArray(),
            "yfr;".toCharArray(), "yicy;".toCharArray(), "yopf;".toCharArray(),
            "yscr;".toCharArray(), "yucy;".toCharArray(), "yuml".toCharArray(),
            "yuml;".toCharArray(), "zacute;".toCharArray(),
            "zcaron;".toCharArray(), "zcy;".toCharArray(),
            "zdot;".toCharArray(), "zeetrf;".toCharArray(),
            "zeta;".toCharArray(), "zfr;".toCharArray(), "zhcy;".toCharArray(),
            "zigrarr;".toCharArray(), "zopf;".toCharArray(),
            "zscr;".toCharArray(), "zwj;".toCharArray(), "zwnj;".toCharArray(), };

    static final @NoLength char[][] VALUES = { { '\u00c6' }, { '\u00c6' },
            { '\u0026' }, { '\u0026' }, { '\u00c1' }, { '\u00c1' },
            { '\u0102' }, { '\u00c2' }, { '\u00c2' }, { '\u0410' },
            { '\ud835', '\udd04' }, { '\u00c0' }, { '\u00c0' }, { '\u0391' },
            { '\u0100' }, { '\u2a53' }, { '\u0104' }, { '\ud835', '\udd38' },
            { '\u2061' }, { '\u00c5' }, { '\u00c5' }, { '\ud835', '\udc9c' },
            { '\u2254' }, { '\u00c3' }, { '\u00c3' }, { '\u00c4' },
            { '\u00c4' }, { '\u2216' }, { '\u2ae7' }, { '\u2306' },
            { '\u0411' }, { '\u2235' }, { '\u212c' }, { '\u0392' },
            { '\ud835', '\udd05' }, { '\ud835', '\udd39' }, { '\u02d8' },
            { '\u212c' }, { '\u224e' }, { '\u0427' }, { '\u00a9' },
            { '\u00a9' }, { '\u0106' }, { '\u22d2' }, { '\u2145' },
            { '\u212d' }, { '\u010c' }, { '\u00c7' }, { '\u00c7' },
            { '\u0108' }, { '\u2230' }, { '\u010a' }, { '\u00b8' },
            { '\u00b7' }, { '\u212d' }, { '\u03a7' }, { '\u2299' },
            { '\u2296' }, { '\u2295' }, { '\u2297' }, { '\u2232' },
            { '\u201d' }, { '\u2019' }, { '\u2237' }, { '\u2a74' },
            { '\u2261' }, { '\u222f' }, { '\u222e' }, { '\u2102' },
            { '\u2210' }, { '\u2233' }, { '\u2a2f' }, { '\ud835', '\udc9e' },
            { '\u22d3' }, { '\u224d' }, { '\u2145' }, { '\u2911' },
            { '\u0402' }, { '\u0405' }, { '\u040f' }, { '\u2021' },
            { '\u21a1' }, { '\u2ae4' }, { '\u010e' }, { '\u0414' },
            { '\u2207' }, { '\u0394' }, { '\ud835', '\udd07' }, { '\u00b4' },
            { '\u02d9' }, { '\u02dd' }, { '\u0060' }, { '\u02dc' },
            { '\u22c4' }, { '\u2146' }, { '\ud835', '\udd3b' }, { '\u00a8' },
            { '\u20dc' }, { '\u2250' }, { '\u222f' }, { '\u00a8' },
            { '\u21d3' }, { '\u21d0' }, { '\u21d4' }, { '\u2ae4' },
            { '\u27f8' }, { '\u27fa' }, { '\u27f9' }, { '\u21d2' },
            { '\u22a8' }, { '\u21d1' }, { '\u21d5' }, { '\u2225' },
            { '\u2193' }, { '\u2913' }, { '\u21f5' }, { '\u0311' },
            { '\u2950' }, { '\u295e' }, { '\u21bd' }, { '\u2956' },
            { '\u295f' }, { '\u21c1' }, { '\u2957' }, { '\u22a4' },
            { '\u21a7' }, { '\u21d3' }, { '\ud835', '\udc9f' }, { '\u0110' },
            { '\u014a' }, { '\u00d0' }, { '\u00d0' }, { '\u00c9' },
            { '\u00c9' }, { '\u011a' }, { '\u00ca' }, { '\u00ca' },
            { '\u042d' }, { '\u0116' }, { '\ud835', '\udd08' }, { '\u00c8' },
            { '\u00c8' }, { '\u2208' }, { '\u0112' }, { '\u25fb' },
            { '\u25ab' }, { '\u0118' }, { '\ud835', '\udd3c' }, { '\u0395' },
            { '\u2a75' }, { '\u2242' }, { '\u21cc' }, { '\u2130' },
            { '\u2a73' }, { '\u0397' }, { '\u00cb' }, { '\u00cb' },
            { '\u2203' }, { '\u2147' }, { '\u0424' }, { '\ud835', '\udd09' },
            { '\u25fc' }, { '\u25aa' }, { '\ud835', '\udd3d' }, { '\u2200' },
            { '\u2131' }, { '\u2131' }, { '\u0403' }, { '\u003e' },
            { '\u003e' }, { '\u0393' }, { '\u03dc' }, { '\u011e' },
            { '\u0122' }, { '\u011c' }, { '\u0413' }, { '\u0120' },
            { '\ud835', '\udd0a' }, { '\u22d9' }, { '\ud835', '\udd3e' },
            { '\u2265' }, { '\u22db' }, { '\u2267' }, { '\u2aa2' },
            { '\u2277' }, { '\u2a7e' }, { '\u2273' }, { '\ud835', '\udca2' },
            { '\u226b' }, { '\u042a' }, { '\u02c7' }, { '\u005e' },
            { '\u0124' }, { '\u210c' }, { '\u210b' }, { '\u210d' },
            { '\u2500' }, { '\u210b' }, { '\u0126' }, { '\u224e' },
            { '\u224f' }, { '\u0415' }, { '\u0132' }, { '\u0401' },
            { '\u00cd' }, { '\u00cd' }, { '\u00ce' }, { '\u00ce' },
            { '\u0418' }, { '\u0130' }, { '\u2111' }, { '\u00cc' },
            { '\u00cc' }, { '\u2111' }, { '\u012a' }, { '\u2148' },
            { '\u21d2' }, { '\u222c' }, { '\u222b' }, { '\u22c2' },
            { '\u2063' }, { '\u2062' }, { '\u012e' }, { '\ud835', '\udd40' },
            { '\u0399' }, { '\u2110' }, { '\u0128' }, { '\u0406' },
            { '\u00cf' }, { '\u00cf' }, { '\u0134' }, { '\u0419' },
            { '\ud835', '\udd0d' }, { '\ud835', '\udd41' },
            { '\ud835', '\udca5' }, { '\u0408' }, { '\u0404' }, { '\u0425' },
            { '\u040c' }, { '\u039a' }, { '\u0136' }, { '\u041a' },
            { '\ud835', '\udd0e' }, { '\ud835', '\udd42' },
            { '\ud835', '\udca6' }, { '\u0409' }, { '\u003c' }, { '\u003c' },
            { '\u0139' }, { '\u039b' }, { '\u27ea' }, { '\u2112' },
            { '\u219e' }, { '\u013d' }, { '\u013b' }, { '\u041b' },
            { '\u27e8' }, { '\u2190' }, { '\u21e4' }, { '\u21c6' },
            { '\u2308' }, { '\u27e6' }, { '\u2961' }, { '\u21c3' },
            { '\u2959' }, { '\u230a' }, { '\u2194' }, { '\u294e' },
            { '\u22a3' }, { '\u21a4' }, { '\u295a' }, { '\u22b2' },
            { '\u29cf' }, { '\u22b4' }, { '\u2951' }, { '\u2960' },
            { '\u21bf' }, { '\u2958' }, { '\u21bc' }, { '\u2952' },
            { '\u21d0' }, { '\u21d4' }, { '\u22da' }, { '\u2266' },
            { '\u2276' }, { '\u2aa1' }, { '\u2a7d' }, { '\u2272' },
            { '\ud835', '\udd0f' }, { '\u22d8' }, { '\u21da' }, { '\u013f' },
            { '\u27f5' }, { '\u27f7' }, { '\u27f6' }, { '\u27f8' },
            { '\u27fa' }, { '\u27f9' }, { '\ud835', '\udd43' }, { '\u2199' },
            { '\u2198' }, { '\u2112' }, { '\u21b0' }, { '\u0141' },
            { '\u226a' }, { '\u2905' }, { '\u041c' }, { '\u205f' },
            { '\u2133' }, { '\ud835', '\udd10' }, { '\u2213' },
            { '\ud835', '\udd44' }, { '\u2133' }, { '\u039c' }, { '\u040a' },
            { '\u0143' }, { '\u0147' }, { '\u0145' }, { '\u041d' },
            { '\u200b' }, { '\u200b' }, { '\u200b' }, { '\u200b' },
            { '\u226b' }, { '\u226a' }, { '\n' }, { '\ud835', '\udd11' },
            { '\u2060' }, { '\u00a0' }, { '\u2115' }, { '\u2aec' },
            { '\u2262' }, { '\u226d' }, { '\u2226' }, { '\u2209' },
            { '\u2260' }, { '\u2204' }, { '\u226f' }, { '\u2271' },
            { '\u2279' }, { '\u2275' }, { '\u22ea' }, { '\u22ec' },
            { '\u226e' }, { '\u2270' }, { '\u2278' }, { '\u2274' },
            { '\u2280' }, { '\u22e0' }, { '\u220c' }, { '\u22eb' },
            { '\u22ed' }, { '\u22e2' }, { '\u22e3' }, { '\u2288' },
            { '\u2281' }, { '\u22e1' }, { '\u2289' }, { '\u2241' },
            { '\u2244' }, { '\u2247' }, { '\u2249' }, { '\u2224' },
            { '\ud835', '\udca9' }, { '\u00d1' }, { '\u00d1' }, { '\u039d' },
            { '\u0152' }, { '\u00d3' }, { '\u00d3' }, { '\u00d4' },
            { '\u00d4' }, { '\u041e' }, { '\u0150' }, { '\ud835', '\udd12' },
            { '\u00d2' }, { '\u00d2' }, { '\u014c' }, { '\u03a9' },
            { '\u039f' }, { '\ud835', '\udd46' }, { '\u201c' }, { '\u2018' },
            { '\u2a54' }, { '\ud835', '\udcaa' }, { '\u00d8' }, { '\u00d8' },
            { '\u00d5' }, { '\u00d5' }, { '\u2a37' }, { '\u00d6' },
            { '\u00d6' }, { '\u00af' }, { '\u23de' }, { '\u23b4' },
            { '\u23dc' }, { '\u2202' }, { '\u041f' }, { '\ud835', '\udd13' },
            { '\u03a6' }, { '\u03a0' }, { '\u00b1' }, { '\u210c' },
            { '\u2119' }, { '\u2abb' }, { '\u227a' }, { '\u2aaf' },
            { '\u227c' }, { '\u227e' }, { '\u2033' }, { '\u220f' },
            { '\u2237' }, { '\u221d' }, { '\ud835', '\udcab' }, { '\u03a8' },
            { '\u0022' }, { '\u0022' }, { '\ud835', '\udd14' }, { '\u211a' },
            { '\ud835', '\udcac' }, { '\u2910' }, { '\u00ae' }, { '\u00ae' },
            { '\u0154' }, { '\u27eb' }, { '\u21a0' }, { '\u2916' },
            { '\u0158' }, { '\u0156' }, { '\u0420' }, { '\u211c' },
            { '\u220b' }, { '\u21cb' }, { '\u296f' }, { '\u211c' },
            { '\u03a1' }, { '\u27e9' }, { '\u2192' }, { '\u21e5' },
            { '\u21c4' }, { '\u2309' }, { '\u27e7' }, { '\u295d' },
            { '\u21c2' }, { '\u2955' }, { '\u230b' }, { '\u22a2' },
            { '\u21a6' }, { '\u295b' }, { '\u22b3' }, { '\u29d0' },
            { '\u22b5' }, { '\u294f' }, { '\u295c' }, { '\u21be' },
            { '\u2954' }, { '\u21c0' }, { '\u2953' }, { '\u21d2' },
            { '\u211d' }, { '\u2970' }, { '\u21db' }, { '\u211b' },
            { '\u21b1' }, { '\u29f4' }, { '\u0429' }, { '\u0428' },
            { '\u042c' }, { '\u015a' }, { '\u2abc' }, { '\u0160' },
            { '\u015e' }, { '\u015c' }, { '\u0421' }, { '\ud835', '\udd16' },
            { '\u2193' }, { '\u2190' }, { '\u2192' }, { '\u2191' },
            { '\u03a3' }, { '\u2218' }, { '\ud835', '\udd4a' }, { '\u221a' },
            { '\u25a1' }, { '\u2293' }, { '\u228f' }, { '\u2291' },
            { '\u2290' }, { '\u2292' }, { '\u2294' }, { '\ud835', '\udcae' },
            { '\u22c6' }, { '\u22d0' }, { '\u22d0' }, { '\u2286' },
            { '\u227b' }, { '\u2ab0' }, { '\u227d' }, { '\u227f' },
            { '\u220b' }, { '\u2211' }, { '\u22d1' }, { '\u2283' },
            { '\u2287' }, { '\u22d1' }, { '\u00de' }, { '\u00de' },
            { '\u2122' }, { '\u040b' }, { '\u0426' }, { '\u0009' },
            { '\u03a4' }, { '\u0164' }, { '\u0162' }, { '\u0422' },
            { '\ud835', '\udd17' }, { '\u2234' }, { '\u0398' }, { '\u2009' },
            { '\u223c' }, { '\u2243' }, { '\u2245' }, { '\u2248' },
            { '\ud835', '\udd4b' }, { '\u20db' }, { '\ud835', '\udcaf' },
            { '\u0166' }, { '\u00da' }, { '\u00da' }, { '\u219f' },
            { '\u2949' }, { '\u040e' }, { '\u016c' }, { '\u00db' },
            { '\u00db' }, { '\u0423' }, { '\u0170' }, { '\ud835', '\udd18' },
            { '\u00d9' }, { '\u00d9' }, { '\u016a' }, { '\u0332' },
            { '\u23df' }, { '\u23b5' }, { '\u23dd' }, { '\u22c3' },
            { '\u228e' }, { '\u0172' }, { '\ud835', '\udd4c' }, { '\u2191' },
            { '\u2912' }, { '\u21c5' }, { '\u2195' }, { '\u296e' },
            { '\u22a5' }, { '\u21a5' }, { '\u21d1' }, { '\u21d5' },
            { '\u2196' }, { '\u2197' }, { '\u03d2' }, { '\u03a5' },
            { '\u016e' }, { '\ud835', '\udcb0' }, { '\u0168' }, { '\u00dc' },
            { '\u00dc' }, { '\u22ab' }, { '\u2aeb' }, { '\u0412' },
            { '\u22a9' }, { '\u2ae6' }, { '\u22c1' }, { '\u2016' },
            { '\u2016' }, { '\u2223' }, { '\u007c' }, { '\u2758' },
            { '\u2240' }, { '\u200a' }, { '\ud835', '\udd19' },
            { '\ud835', '\udd4d' }, { '\ud835', '\udcb1' }, { '\u22aa' },
            { '\u0174' }, { '\u22c0' }, { '\ud835', '\udd1a' },
            { '\ud835', '\udd4e' }, { '\ud835', '\udcb2' },
            { '\ud835', '\udd1b' }, { '\u039e' }, { '\ud835', '\udd4f' },
            { '\ud835', '\udcb3' }, { '\u042f' }, { '\u0407' }, { '\u042e' },
            { '\u00dd' }, { '\u00dd' }, { '\u0176' }, { '\u042b' },
            { '\ud835', '\udd1c' }, { '\ud835', '\udd50' },
            { '\ud835', '\udcb4' }, { '\u0178' }, { '\u0416' }, { '\u0179' },
            { '\u017d' }, { '\u0417' }, { '\u017b' }, { '\u200b' },
            { '\u0396' }, { '\u2128' }, { '\u2124' }, { '\ud835', '\udcb5' },
            { '\u00e1' }, { '\u00e1' }, { '\u0103' }, { '\u223e' },
            { '\u223f' }, { '\u00e2' }, { '\u00e2' }, { '\u00b4' },
            { '\u00b4' }, { '\u0430' }, { '\u00e6' }, { '\u00e6' },
            { '\u2061' }, { '\ud835', '\udd1e' }, { '\u00e0' }, { '\u00e0' },
            { '\u2135' }, { '\u2135' }, { '\u03b1' }, { '\u0101' },
            { '\u2a3f' }, { '\u0026' }, { '\u0026' }, { '\u2227' },
            { '\u2a55' }, { '\u2a5c' }, { '\u2a58' }, { '\u2a5a' },
            { '\u2220' }, { '\u29a4' }, { '\u2220' }, { '\u2221' },
            { '\u29a8' }, { '\u29a9' }, { '\u29aa' }, { '\u29ab' },
            { '\u29ac' }, { '\u29ad' }, { '\u29ae' }, { '\u29af' },
            { '\u221f' }, { '\u22be' }, { '\u299d' }, { '\u2222' },
            { '\u212b' }, { '\u237c' }, { '\u0105' }, { '\ud835', '\udd52' },
            { '\u2248' }, { '\u2a70' }, { '\u2a6f' }, { '\u224a' },
            { '\u224b' }, { '\'' }, { '\u2248' }, { '\u224a' }, { '\u00e5' },
            { '\u00e5' }, { '\ud835', '\udcb6' }, { '\u002a' }, { '\u2248' },
            { '\u224d' }, { '\u00e3' }, { '\u00e3' }, { '\u00e4' },
            { '\u00e4' }, { '\u2233' }, { '\u2a11' }, { '\u2aed' },
            { '\u224c' }, { '\u03f6' }, { '\u2035' }, { '\u223d' },
            { '\u22cd' }, { '\u22bd' }, { '\u2305' }, { '\u2305' },
            { '\u23b5' }, { '\u23b6' }, { '\u224c' }, { '\u0431' },
            { '\u201e' }, { '\u2235' }, { '\u2235' }, { '\u29b0' },
            { '\u03f6' }, { '\u212c' }, { '\u03b2' }, { '\u2136' },
            { '\u226c' }, { '\ud835', '\udd1f' }, { '\u22c2' }, { '\u25ef' },
            { '\u22c3' }, { '\u2a00' }, { '\u2a01' }, { '\u2a02' },
            { '\u2a06' }, { '\u2605' }, { '\u25bd' }, { '\u25b3' },
            { '\u2a04' }, { '\u22c1' }, { '\u22c0' }, { '\u290d' },
            { '\u29eb' }, { '\u25aa' }, { '\u25b4' }, { '\u25be' },
            { '\u25c2' }, { '\u25b8' }, { '\u2423' }, { '\u2592' },
            { '\u2591' }, { '\u2593' }, { '\u2588' }, { '\u2310' },
            { '\ud835', '\udd53' }, { '\u22a5' }, { '\u22a5' }, { '\u22c8' },
            { '\u2557' }, { '\u2554' }, { '\u2556' }, { '\u2553' },
            { '\u2550' }, { '\u2566' }, { '\u2569' }, { '\u2564' },
            { '\u2567' }, { '\u255d' }, { '\u255a' }, { '\u255c' },
            { '\u2559' }, { '\u2551' }, { '\u256c' }, { '\u2563' },
            { '\u2560' }, { '\u256b' }, { '\u2562' }, { '\u255f' },
            { '\u29c9' }, { '\u2555' }, { '\u2552' }, { '\u2510' },
            { '\u250c' }, { '\u2500' }, { '\u2565' }, { '\u2568' },
            { '\u252c' }, { '\u2534' }, { '\u229f' }, { '\u229e' },
            { '\u22a0' }, { '\u255b' }, { '\u2558' }, { '\u2518' },
            { '\u2514' }, { '\u2502' }, { '\u256a' }, { '\u2561' },
            { '\u255e' }, { '\u253c' }, { '\u2524' }, { '\u251c' },
            { '\u2035' }, { '\u02d8' }, { '\u00a6' }, { '\u00a6' },
            { '\ud835', '\udcb7' }, { '\u204f' }, { '\u223d' }, { '\u22cd' },
            { '\\' }, { '\u29c5' }, { '\u2022' }, { '\u2022' }, { '\u224e' },
            { '\u2aae' }, { '\u224f' }, { '\u224f' }, { '\u0107' },
            { '\u2229' }, { '\u2a44' }, { '\u2a49' }, { '\u2a4b' },
            { '\u2a47' }, { '\u2a40' }, { '\u2041' }, { '\u02c7' },
            { '\u2a4d' }, { '\u010d' }, { '\u00e7' }, { '\u00e7' },
            { '\u0109' }, { '\u2a4c' }, { '\u2a50' }, { '\u010b' },
            { '\u00b8' }, { '\u00b8' }, { '\u29b2' }, { '\u00a2' },
            { '\u00a2' }, { '\u00b7' }, { '\ud835', '\udd20' }, { '\u0447' },
            { '\u2713' }, { '\u2713' }, { '\u03c7' }, { '\u25cb' },
            { '\u29c3' }, { '\u02c6' }, { '\u2257' }, { '\u21ba' },
            { '\u21bb' }, { '\u00ae' }, { '\u24c8' }, { '\u229b' },
            { '\u229a' }, { '\u229d' }, { '\u2257' }, { '\u2a10' },
            { '\u2aef' }, { '\u29c2' }, { '\u2663' }, { '\u2663' },
            { '\u003a' }, { '\u2254' }, { '\u2254' }, { '\u002c' },
            { '\u0040' }, { '\u2201' }, { '\u2218' }, { '\u2201' },
            { '\u2102' }, { '\u2245' }, { '\u2a6d' }, { '\u222e' },
            { '\ud835', '\udd54' }, { '\u2210' }, { '\u00a9' }, { '\u00a9' },
            { '\u2117' }, { '\u21b5' }, { '\u2717' }, { '\ud835', '\udcb8' },
            { '\u2acf' }, { '\u2ad1' }, { '\u2ad0' }, { '\u2ad2' },
            { '\u22ef' }, { '\u2938' }, { '\u2935' }, { '\u22de' },
            { '\u22df' }, { '\u21b6' }, { '\u293d' }, { '\u222a' },
            { '\u2a48' }, { '\u2a46' }, { '\u2a4a' }, { '\u228d' },
            { '\u2a45' }, { '\u21b7' }, { '\u293c' }, { '\u22de' },
            { '\u22df' }, { '\u22ce' }, { '\u22cf' }, { '\u00a4' },
            { '\u00a4' }, { '\u21b6' }, { '\u21b7' }, { '\u22ce' },
            { '\u22cf' }, { '\u2232' }, { '\u2231' }, { '\u232d' },
            { '\u21d3' }, { '\u2965' }, { '\u2020' }, { '\u2138' },
            { '\u2193' }, { '\u2010' }, { '\u22a3' }, { '\u290f' },
            { '\u02dd' }, { '\u010f' }, { '\u0434' }, { '\u2146' },
            { '\u2021' }, { '\u21ca' }, { '\u2a77' }, { '\u00b0' },
            { '\u00b0' }, { '\u03b4' }, { '\u29b1' }, { '\u297f' },
            { '\ud835', '\udd21' }, { '\u21c3' }, { '\u21c2' }, { '\u22c4' },
            { '\u22c4' }, { '\u2666' }, { '\u2666' }, { '\u00a8' },
            { '\u03dd' }, { '\u22f2' }, { '\u00f7' }, { '\u00f7' },
            { '\u00f7' }, { '\u22c7' }, { '\u22c7' }, { '\u0452' },
            { '\u231e' }, { '\u230d' }, { '\u0024' }, { '\ud835', '\udd55' },
            { '\u02d9' }, { '\u2250' }, { '\u2251' }, { '\u2238' },
            { '\u2214' }, { '\u22a1' }, { '\u2306' }, { '\u2193' },
            { '\u21ca' }, { '\u21c3' }, { '\u21c2' }, { '\u2910' },
            { '\u231f' }, { '\u230c' }, { '\ud835', '\udcb9' }, { '\u0455' },
            { '\u29f6' }, { '\u0111' }, { '\u22f1' }, { '\u25bf' },
            { '\u25be' }, { '\u21f5' }, { '\u296f' }, { '\u29a6' },
            { '\u045f' }, { '\u27ff' }, { '\u2a77' }, { '\u2251' },
            { '\u00e9' }, { '\u00e9' }, { '\u2a6e' }, { '\u011b' },
            { '\u2256' }, { '\u00ea' }, { '\u00ea' }, { '\u2255' },
            { '\u044d' }, { '\u0117' }, { '\u2147' }, { '\u2252' },
            { '\ud835', '\udd22' }, { '\u2a9a' }, { '\u00e8' }, { '\u00e8' },
            { '\u2a96' }, { '\u2a98' }, { '\u2a99' }, { '\u23e7' },
            { '\u2113' }, { '\u2a95' }, { '\u2a97' }, { '\u0113' },
            { '\u2205' }, { '\u2205' }, { '\u2205' }, { '\u2004' },
            { '\u2005' }, { '\u2003' }, { '\u014b' }, { '\u2002' },
            { '\u0119' }, { '\ud835', '\udd56' }, { '\u22d5' }, { '\u29e3' },
            { '\u2a71' }, { '\u03f5' }, { '\u03b5' }, { '\u03b5' },
            { '\u2256' }, { '\u2255' }, { '\u2242' }, { '\u2a96' },
            { '\u2a95' }, { '\u003d' }, { '\u225f' }, { '\u2261' },
            { '\u2a78' }, { '\u29e5' }, { '\u2253' }, { '\u2971' },
            { '\u212f' }, { '\u2250' }, { '\u2242' }, { '\u03b7' },
            { '\u00f0' }, { '\u00f0' }, { '\u00eb' }, { '\u00eb' },
            { '\u20ac' }, { '\u0021' }, { '\u2203' }, { '\u2130' },
            { '\u2147' }, { '\u2252' }, { '\u0444' }, { '\u2640' },
            { '\ufb03' }, { '\ufb00' }, { '\ufb04' }, { '\ud835', '\udd23' },
            { '\ufb01' }, { '\u266d' }, { '\ufb02' }, { '\u25b1' },
            { '\u0192' }, { '\ud835', '\udd57' }, { '\u2200' }, { '\u22d4' },
            { '\u2ad9' }, { '\u2a0d' }, { '\u00bd' }, { '\u00bd' },
            { '\u2153' }, { '\u00bc' }, { '\u00bc' }, { '\u2155' },
            { '\u2159' }, { '\u215b' }, { '\u2154' }, { '\u2156' },
            { '\u00be' }, { '\u00be' }, { '\u2157' }, { '\u215c' },
            { '\u2158' }, { '\u215a' }, { '\u215d' }, { '\u215e' },
            { '\u2044' }, { '\u2322' }, { '\ud835', '\udcbb' }, { '\u2267' },
            { '\u2a8c' }, { '\u01f5' }, { '\u03b3' }, { '\u03dd' },
            { '\u2a86' }, { '\u011f' }, { '\u011d' }, { '\u0433' },
            { '\u0121' }, { '\u2265' }, { '\u22db' }, { '\u2265' },
            { '\u2267' }, { '\u2a7e' }, { '\u2a7e' }, { '\u2aa9' },
            { '\u2a80' }, { '\u2a82' }, { '\u2a84' }, { '\u2a94' },
            { '\ud835', '\udd24' }, { '\u226b' }, { '\u22d9' }, { '\u2137' },
            { '\u0453' }, { '\u2277' }, { '\u2a92' }, { '\u2aa5' },
            { '\u2aa4' }, { '\u2269' }, { '\u2a8a' }, { '\u2a8a' },
            { '\u2a88' }, { '\u2a88' }, { '\u2269' }, { '\u22e7' },
            { '\ud835', '\udd58' }, { '\u0060' }, { '\u210a' }, { '\u2273' },
            { '\u2a8e' }, { '\u2a90' }, { '\u003e' }, { '\u003e' },
            { '\u2aa7' }, { '\u2a7a' }, { '\u22d7' }, { '\u2995' },
            { '\u2a7c' }, { '\u2a86' }, { '\u2978' }, { '\u22d7' },
            { '\u22db' }, { '\u2a8c' }, { '\u2277' }, { '\u2273' },
            { '\u21d4' }, { '\u200a' }, { '\u00bd' }, { '\u210b' },
            { '\u044a' }, { '\u2194' }, { '\u2948' }, { '\u21ad' },
            { '\u210f' }, { '\u0125' }, { '\u2665' }, { '\u2665' },
            { '\u2026' }, { '\u22b9' }, { '\ud835', '\udd25' }, { '\u2925' },
            { '\u2926' }, { '\u21ff' }, { '\u223b' }, { '\u21a9' },
            { '\u21aa' }, { '\ud835', '\udd59' }, { '\u2015' },
            { '\ud835', '\udcbd' }, { '\u210f' }, { '\u0127' }, { '\u2043' },
            { '\u2010' }, { '\u00ed' }, { '\u00ed' }, { '\u2063' },
            { '\u00ee' }, { '\u00ee' }, { '\u0438' }, { '\u0435' },
            { '\u00a1' }, { '\u00a1' }, { '\u21d4' }, { '\ud835', '\udd26' },
            { '\u00ec' }, { '\u00ec' }, { '\u2148' }, { '\u2a0c' },
            { '\u222d' }, { '\u29dc' }, { '\u2129' }, { '\u0133' },
            { '\u012b' }, { '\u2111' }, { '\u2110' }, { '\u2111' },
            { '\u0131' }, { '\u22b7' }, { '\u01b5' }, { '\u2208' },
            { '\u2105' }, { '\u221e' }, { '\u29dd' }, { '\u0131' },
            { '\u222b' }, { '\u22ba' }, { '\u2124' }, { '\u22ba' },
            { '\u2a17' }, { '\u2a3c' }, { '\u0451' }, { '\u012f' },
            { '\ud835', '\udd5a' }, { '\u03b9' }, { '\u2a3c' }, { '\u00bf' },
            { '\u00bf' }, { '\ud835', '\udcbe' }, { '\u2208' }, { '\u22f9' },
            { '\u22f5' }, { '\u22f4' }, { '\u22f3' }, { '\u2208' },
            { '\u2062' }, { '\u0129' }, { '\u0456' }, { '\u00ef' },
            { '\u00ef' }, { '\u0135' }, { '\u0439' }, { '\ud835', '\udd27' },
            { '\u0237' }, { '\ud835', '\udd5b' }, { '\ud835', '\udcbf' },
            { '\u0458' }, { '\u0454' }, { '\u03ba' }, { '\u03f0' },
            { '\u0137' }, { '\u043a' }, { '\ud835', '\udd28' }, { '\u0138' },
            { '\u0445' }, { '\u045c' }, { '\ud835', '\udd5c' },
            { '\ud835', '\udcc0' }, { '\u21da' }, { '\u21d0' }, { '\u291b' },
            { '\u290e' }, { '\u2266' }, { '\u2a8b' }, { '\u2962' },
            { '\u013a' }, { '\u29b4' }, { '\u2112' }, { '\u03bb' },
            { '\u27e8' }, { '\u2991' }, { '\u27e8' }, { '\u2a85' },
            { '\u00ab' }, { '\u00ab' }, { '\u2190' }, { '\u21e4' },
            { '\u291f' }, { '\u291d' }, { '\u21a9' }, { '\u21ab' },
            { '\u2939' }, { '\u2973' }, { '\u21a2' }, { '\u2aab' },
            { '\u2919' }, { '\u2aad' }, { '\u290c' }, { '\u2772' },
            { '\u007b' }, { '\u005b' }, { '\u298b' }, { '\u298f' },
            { '\u298d' }, { '\u013e' }, { '\u013c' }, { '\u2308' },
            { '\u007b' }, { '\u043b' }, { '\u2936' }, { '\u201c' },
            { '\u201e' }, { '\u2967' }, { '\u294b' }, { '\u21b2' },
            { '\u2264' }, { '\u2190' }, { '\u21a2' }, { '\u21bd' },
            { '\u21bc' }, { '\u21c7' }, { '\u2194' }, { '\u21c6' },
            { '\u21cb' }, { '\u21ad' }, { '\u22cb' }, { '\u22da' },
            { '\u2264' }, { '\u2266' }, { '\u2a7d' }, { '\u2a7d' },
            { '\u2aa8' }, { '\u2a7f' }, { '\u2a81' }, { '\u2a83' },
            { '\u2a93' }, { '\u2a85' }, { '\u22d6' }, { '\u22da' },
            { '\u2a8b' }, { '\u2276' }, { '\u2272' }, { '\u297c' },
            { '\u230a' }, { '\ud835', '\udd29' }, { '\u2276' }, { '\u2a91' },
            { '\u21bd' }, { '\u21bc' }, { '\u296a' }, { '\u2584' },
            { '\u0459' }, { '\u226a' }, { '\u21c7' }, { '\u231e' },
            { '\u296b' }, { '\u25fa' }, { '\u0140' }, { '\u23b0' },
            { '\u23b0' }, { '\u2268' }, { '\u2a89' }, { '\u2a89' },
            { '\u2a87' }, { '\u2a87' }, { '\u2268' }, { '\u22e6' },
            { '\u27ec' }, { '\u21fd' }, { '\u27e6' }, { '\u27f5' },
            { '\u27f7' }, { '\u27fc' }, { '\u27f6' }, { '\u21ab' },
            { '\u21ac' }, { '\u2985' }, { '\ud835', '\udd5d' }, { '\u2a2d' },
            { '\u2a34' }, { '\u2217' }, { '\u005f' }, { '\u25ca' },
            { '\u25ca' }, { '\u29eb' }, { '\u0028' }, { '\u2993' },
            { '\u21c6' }, { '\u231f' }, { '\u21cb' }, { '\u296d' },
            { '\u200e' }, { '\u22bf' }, { '\u2039' }, { '\ud835', '\udcc1' },
            { '\u21b0' }, { '\u2272' }, { '\u2a8d' }, { '\u2a8f' },
            { '\u005b' }, { '\u2018' }, { '\u201a' }, { '\u0142' },
            { '\u003c' }, { '\u003c' }, { '\u2aa6' }, { '\u2a79' },
            { '\u22d6' }, { '\u22cb' }, { '\u22c9' }, { '\u2976' },
            { '\u2a7b' }, { '\u2996' }, { '\u25c3' }, { '\u22b4' },
            { '\u25c2' }, { '\u294a' }, { '\u2966' }, { '\u223a' },
            { '\u00af' }, { '\u00af' }, { '\u2642' }, { '\u2720' },
            { '\u2720' }, { '\u21a6' }, { '\u21a6' }, { '\u21a7' },
            { '\u21a4' }, { '\u21a5' }, { '\u25ae' }, { '\u2a29' },
            { '\u043c' }, { '\u2014' }, { '\u2221' }, { '\ud835', '\udd2a' },
            { '\u2127' }, { '\u00b5' }, { '\u00b5' }, { '\u2223' },
            { '\u002a' }, { '\u2af0' }, { '\u00b7' }, { '\u00b7' },
            { '\u2212' }, { '\u229f' }, { '\u2238' }, { '\u2a2a' },
            { '\u2adb' }, { '\u2026' }, { '\u2213' }, { '\u22a7' },
            { '\ud835', '\udd5e' }, { '\u2213' }, { '\ud835', '\udcc2' },
            { '\u223e' }, { '\u03bc' }, { '\u22b8' }, { '\u22b8' },
            { '\u21cd' }, { '\u21ce' }, { '\u21cf' }, { '\u22af' },
            { '\u22ae' }, { '\u2207' }, { '\u0144' }, { '\u2249' },
            { '\u0149' }, { '\u2249' }, { '\u266e' }, { '\u266e' },
            { '\u2115' }, { '\u00a0' }, { '\u00a0' }, { '\u2a43' },
            { '\u0148' }, { '\u0146' }, { '\u2247' }, { '\u2a42' },
            { '\u043d' }, { '\u2013' }, { '\u2260' }, { '\u21d7' },
            { '\u2924' }, { '\u2197' }, { '\u2197' }, { '\u2262' },
            { '\u2928' }, { '\u2204' }, { '\u2204' }, { '\ud835', '\udd2b' },
            { '\u2271' }, { '\u2271' }, { '\u2275' }, { '\u226f' },
            { '\u226f' }, { '\u21ce' }, { '\u21ae' }, { '\u2af2' },
            { '\u220b' }, { '\u22fc' }, { '\u22fa' }, { '\u220b' },
            { '\u045a' }, { '\u21cd' }, { '\u219a' }, { '\u2025' },
            { '\u2270' }, { '\u219a' }, { '\u21ae' }, { '\u2270' },
            { '\u226e' }, { '\u2274' }, { '\u226e' }, { '\u22ea' },
            { '\u22ec' }, { '\u2224' }, { '\ud835', '\udd5f' }, { '\u00ac' },
            { '\u00ac' }, { '\u2209' }, { '\u2209' }, { '\u22f7' },
            { '\u22f6' }, { '\u220c' }, { '\u220c' }, { '\u22fe' },
            { '\u22fd' }, { '\u2226' }, { '\u2226' }, { '\u2a14' },
            { '\u2280' }, { '\u22e0' }, { '\u2280' }, { '\u21cf' },
            { '\u219b' }, { '\u219b' }, { '\u22eb' }, { '\u22ed' },
            { '\u2281' }, { '\u22e1' }, { '\ud835', '\udcc3' }, { '\u2224' },
            { '\u2226' }, { '\u2241' }, { '\u2244' }, { '\u2244' },
            { '\u2224' }, { '\u2226' }, { '\u22e2' }, { '\u22e3' },
            { '\u2284' }, { '\u2288' }, { '\u2288' }, { '\u2281' },
            { '\u2285' }, { '\u2289' }, { '\u2289' }, { '\u2279' },
            { '\u00f1' }, { '\u00f1' }, { '\u2278' }, { '\u22ea' },
            { '\u22ec' }, { '\u22eb' }, { '\u22ed' }, { '\u03bd' },
            { '\u0023' }, { '\u2116' }, { '\u2007' }, { '\u22ad' },
            { '\u2904' }, { '\u22ac' }, { '\u29de' }, { '\u2902' },
            { '\u2903' }, { '\u21d6' }, { '\u2923' }, { '\u2196' },
            { '\u2196' }, { '\u2927' }, { '\u24c8' }, { '\u00f3' },
            { '\u00f3' }, { '\u229b' }, { '\u229a' }, { '\u00f4' },
            { '\u00f4' }, { '\u043e' }, { '\u229d' }, { '\u0151' },
            { '\u2a38' }, { '\u2299' }, { '\u29bc' }, { '\u0153' },
            { '\u29bf' }, { '\ud835', '\udd2c' }, { '\u02db' }, { '\u00f2' },
            { '\u00f2' }, { '\u29c1' }, { '\u29b5' }, { '\u2126' },
            { '\u222e' }, { '\u21ba' }, { '\u29be' }, { '\u29bb' },
            { '\u203e' }, { '\u29c0' }, { '\u014d' }, { '\u03c9' },
            { '\u03bf' }, { '\u29b6' }, { '\u2296' }, { '\ud835', '\udd60' },
            { '\u29b7' }, { '\u29b9' }, { '\u2295' }, { '\u2228' },
            { '\u21bb' }, { '\u2a5d' }, { '\u2134' }, { '\u2134' },
            { '\u00aa' }, { '\u00aa' }, { '\u00ba' }, { '\u00ba' },
            { '\u22b6' }, { '\u2a56' }, { '\u2a57' }, { '\u2a5b' },
            { '\u2134' }, { '\u00f8' }, { '\u00f8' }, { '\u2298' },
            { '\u00f5' }, { '\u00f5' }, { '\u2297' }, { '\u2a36' },
            { '\u00f6' }, { '\u00f6' }, { '\u233d' }, { '\u2225' },
            { '\u00b6' }, { '\u00b6' }, { '\u2225' }, { '\u2af3' },
            { '\u2afd' }, { '\u2202' }, { '\u043f' }, { '\u0025' },
            { '\u002e' }, { '\u2030' }, { '\u22a5' }, { '\u2031' },
            { '\ud835', '\udd2d' }, { '\u03c6' }, { '\u03c6' }, { '\u2133' },
            { '\u260e' }, { '\u03c0' }, { '\u22d4' }, { '\u03d6' },
            { '\u210f' }, { '\u210e' }, { '\u210f' }, { '\u002b' },
            { '\u2a23' }, { '\u229e' }, { '\u2a22' }, { '\u2214' },
            { '\u2a25' }, { '\u2a72' }, { '\u00b1' }, { '\u00b1' },
            { '\u2a26' }, { '\u2a27' }, { '\u00b1' }, { '\u2a15' },
            { '\ud835', '\udd61' }, { '\u00a3' }, { '\u00a3' }, { '\u227a' },
            { '\u2ab3' }, { '\u2ab7' }, { '\u227c' }, { '\u2aaf' },
            { '\u227a' }, { '\u2ab7' }, { '\u227c' }, { '\u2aaf' },
            { '\u2ab9' }, { '\u2ab5' }, { '\u22e8' }, { '\u227e' },
            { '\u2032' }, { '\u2119' }, { '\u2ab5' }, { '\u2ab9' },
            { '\u22e8' }, { '\u220f' }, { '\u232e' }, { '\u2312' },
            { '\u2313' }, { '\u221d' }, { '\u221d' }, { '\u227e' },
            { '\u22b0' }, { '\ud835', '\udcc5' }, { '\u03c8' }, { '\u2008' },
            { '\ud835', '\udd2e' }, { '\u2a0c' }, { '\ud835', '\udd62' },
            { '\u2057' }, { '\ud835', '\udcc6' }, { '\u210d' }, { '\u2a16' },
            { '\u003f' }, { '\u225f' }, { '\u0022' }, { '\u0022' },
            { '\u21db' }, { '\u21d2' }, { '\u291c' }, { '\u290f' },
            { '\u2964' }, { '\u29da' }, { '\u0155' }, { '\u221a' },
            { '\u29b3' }, { '\u27e9' }, { '\u2992' }, { '\u29a5' },
            { '\u27e9' }, { '\u00bb' }, { '\u00bb' }, { '\u2192' },
            { '\u2975' }, { '\u21e5' }, { '\u2920' }, { '\u2933' },
            { '\u291e' }, { '\u21aa' }, { '\u21ac' }, { '\u2945' },
            { '\u2974' }, { '\u21a3' }, { '\u219d' }, { '\u291a' },
            { '\u2236' }, { '\u211a' }, { '\u290d' }, { '\u2773' },
            { '\u007d' }, { '\u005d' }, { '\u298c' }, { '\u298e' },
            { '\u2990' }, { '\u0159' }, { '\u0157' }, { '\u2309' },
            { '\u007d' }, { '\u0440' }, { '\u2937' }, { '\u2969' },
            { '\u201d' }, { '\u201d' }, { '\u21b3' }, { '\u211c' },
            { '\u211b' }, { '\u211c' }, { '\u211d' }, { '\u25ad' },
            { '\u00ae' }, { '\u00ae' }, { '\u297d' }, { '\u230b' },
            { '\ud835', '\udd2f' }, { '\u21c1' }, { '\u21c0' }, { '\u296c' },
            { '\u03c1' }, { '\u03f1' }, { '\u2192' }, { '\u21a3' },
            { '\u21c1' }, { '\u21c0' }, { '\u21c4' }, { '\u21cc' },
            { '\u21c9' }, { '\u219d' }, { '\u22cc' }, { '\u02da' },
            { '\u2253' }, { '\u21c4' }, { '\u21cc' }, { '\u200f' },
            { '\u23b1' }, { '\u23b1' }, { '\u2aee' }, { '\u27ed' },
            { '\u21fe' }, { '\u27e7' }, { '\u2986' }, { '\ud835', '\udd63' },
            { '\u2a2e' }, { '\u2a35' }, { '\u0029' }, { '\u2994' },
            { '\u2a12' }, { '\u21c9' }, { '\u203a' }, { '\ud835', '\udcc7' },
            { '\u21b1' }, { '\u005d' }, { '\u2019' }, { '\u2019' },
            { '\u22cc' }, { '\u22ca' }, { '\u25b9' }, { '\u22b5' },
            { '\u25b8' }, { '\u29ce' }, { '\u2968' }, { '\u211e' },
            { '\u015b' }, { '\u201a' }, { '\u227b' }, { '\u2ab4' },
            { '\u2ab8' }, { '\u0161' }, { '\u227d' }, { '\u2ab0' },
            { '\u015f' }, { '\u015d' }, { '\u2ab6' }, { '\u2aba' },
            { '\u22e9' }, { '\u2a13' }, { '\u227f' }, { '\u0441' },
            { '\u22c5' }, { '\u22a1' }, { '\u2a66' }, { '\u21d8' },
            { '\u2925' }, { '\u2198' }, { '\u2198' }, { '\u00a7' },
            { '\u00a7' }, { '\u003b' }, { '\u2929' }, { '\u2216' },
            { '\u2216' }, { '\u2736' }, { '\ud835', '\udd30' }, { '\u2322' },
            { '\u266f' }, { '\u0449' }, { '\u0448' }, { '\u2223' },
            { '\u2225' }, { '\u00ad' }, { '\u00ad' }, { '\u03c3' },
            { '\u03c2' }, { '\u03c2' }, { '\u223c' }, { '\u2a6a' },
            { '\u2243' }, { '\u2243' }, { '\u2a9e' }, { '\u2aa0' },
            { '\u2a9d' }, { '\u2a9f' }, { '\u2246' }, { '\u2a24' },
            { '\u2972' }, { '\u2190' }, { '\u2216' }, { '\u2a33' },
            { '\u29e4' }, { '\u2223' }, { '\u2323' }, { '\u2aaa' },
            { '\u2aac' }, { '\u044c' }, { '\u002f' }, { '\u29c4' },
            { '\u233f' }, { '\ud835', '\udd64' }, { '\u2660' }, { '\u2660' },
            { '\u2225' }, { '\u2293' }, { '\u2294' }, { '\u228f' },
            { '\u2291' }, { '\u228f' }, { '\u2291' }, { '\u2290' },
            { '\u2292' }, { '\u2290' }, { '\u2292' }, { '\u25a1' },
            { '\u25a1' }, { '\u25aa' }, { '\u25aa' }, { '\u2192' },
            { '\ud835', '\udcc8' }, { '\u2216' }, { '\u2323' }, { '\u22c6' },
            { '\u2606' }, { '\u2605' }, { '\u03f5' }, { '\u03d5' },
            { '\u00af' }, { '\u2282' }, { '\u2ac5' }, { '\u2abd' },
            { '\u2286' }, { '\u2ac3' }, { '\u2ac1' }, { '\u2acb' },
            { '\u228a' }, { '\u2abf' }, { '\u2979' }, { '\u2282' },
            { '\u2286' }, { '\u2ac5' }, { '\u228a' }, { '\u2acb' },
            { '\u2ac7' }, { '\u2ad5' }, { '\u2ad3' }, { '\u227b' },
            { '\u2ab8' }, { '\u227d' }, { '\u2ab0' }, { '\u2aba' },
            { '\u2ab6' }, { '\u22e9' }, { '\u227f' }, { '\u2211' },
            { '\u266a' }, { '\u00b9' }, { '\u00b9' }, { '\u00b2' },
            { '\u00b2' }, { '\u00b3' }, { '\u00b3' }, { '\u2283' },
            { '\u2ac6' }, { '\u2abe' }, { '\u2ad8' }, { '\u2287' },
            { '\u2ac4' }, { '\u2ad7' }, { '\u297b' }, { '\u2ac2' },
            { '\u2acc' }, { '\u228b' }, { '\u2ac0' }, { '\u2283' },
            { '\u2287' }, { '\u2ac6' }, { '\u228b' }, { '\u2acc' },
            { '\u2ac8' }, { '\u2ad4' }, { '\u2ad6' }, { '\u21d9' },
            { '\u2926' }, { '\u2199' }, { '\u2199' }, { '\u292a' },
            { '\u00df' }, { '\u00df' }, { '\u2316' }, { '\u03c4' },
            { '\u23b4' }, { '\u0165' }, { '\u0163' }, { '\u0442' },
            { '\u20db' }, { '\u2315' }, { '\ud835', '\udd31' }, { '\u2234' },
            { '\u2234' }, { '\u03b8' }, { '\u03d1' }, { '\u03d1' },
            { '\u2248' }, { '\u223c' }, { '\u2009' }, { '\u2248' },
            { '\u223c' }, { '\u00fe' }, { '\u00fe' }, { '\u02dc' },
            { '\u00d7' }, { '\u00d7' }, { '\u22a0' }, { '\u2a31' },
            { '\u2a30' }, { '\u222d' }, { '\u2928' }, { '\u22a4' },
            { '\u2336' }, { '\u2af1' }, { '\ud835', '\udd65' }, { '\u2ada' },
            { '\u2929' }, { '\u2034' }, { '\u2122' }, { '\u25b5' },
            { '\u25bf' }, { '\u25c3' }, { '\u22b4' }, { '\u225c' },
            { '\u25b9' }, { '\u22b5' }, { '\u25ec' }, { '\u225c' },
            { '\u2a3a' }, { '\u2a39' }, { '\u29cd' }, { '\u2a3b' },
            { '\u23e2' }, { '\ud835', '\udcc9' }, { '\u0446' }, { '\u045b' },
            { '\u0167' }, { '\u226c' }, { '\u219e' }, { '\u21a0' },
            { '\u21d1' }, { '\u2963' }, { '\u00fa' }, { '\u00fa' },
            { '\u2191' }, { '\u045e' }, { '\u016d' }, { '\u00fb' },
            { '\u00fb' }, { '\u0443' }, { '\u21c5' }, { '\u0171' },
            { '\u296e' }, { '\u297e' }, { '\ud835', '\udd32' }, { '\u00f9' },
            { '\u00f9' }, { '\u21bf' }, { '\u21be' }, { '\u2580' },
            { '\u231c' }, { '\u231c' }, { '\u230f' }, { '\u25f8' },
            { '\u016b' }, { '\u00a8' }, { '\u00a8' }, { '\u0173' },
            { '\ud835', '\udd66' }, { '\u2191' }, { '\u2195' }, { '\u21bf' },
            { '\u21be' }, { '\u228e' }, { '\u03c5' }, { '\u03d2' },
            { '\u03c5' }, { '\u21c8' }, { '\u231d' }, { '\u231d' },
            { '\u230e' }, { '\u016f' }, { '\u25f9' }, { '\ud835', '\udcca' },
            { '\u22f0' }, { '\u0169' }, { '\u25b5' }, { '\u25b4' },
            { '\u21c8' }, { '\u00fc' }, { '\u00fc' }, { '\u29a7' },
            { '\u21d5' }, { '\u2ae8' }, { '\u2ae9' }, { '\u22a8' },
            { '\u299c' }, { '\u03b5' }, { '\u03f0' }, { '\u2205' },
            { '\u03c6' }, { '\u03d6' }, { '\u221d' }, { '\u2195' },
            { '\u03f1' }, { '\u03c2' }, { '\u03d1' }, { '\u22b2' },
            { '\u22b3' }, { '\u0432' }, { '\u22a2' }, { '\u2228' },
            { '\u22bb' }, { '\u225a' }, { '\u22ee' }, { '\u007c' },
            { '\u007c' }, { '\ud835', '\udd33' }, { '\u22b2' },
            { '\ud835', '\udd67' }, { '\u221d' }, { '\u22b3' },
            { '\ud835', '\udccb' }, { '\u299a' }, { '\u0175' }, { '\u2a5f' },
            { '\u2227' }, { '\u2259' }, { '\u2118' }, { '\ud835', '\udd34' },
            { '\ud835', '\udd68' }, { '\u2118' }, { '\u2240' }, { '\u2240' },
            { '\ud835', '\udccc' }, { '\u22c2' }, { '\u25ef' }, { '\u22c3' },
            { '\u25bd' }, { '\ud835', '\udd35' }, { '\u27fa' }, { '\u27f7' },
            { '\u03be' }, { '\u27f8' }, { '\u27f5' }, { '\u27fc' },
            { '\u22fb' }, { '\u2a00' }, { '\ud835', '\udd69' }, { '\u2a01' },
            { '\u2a02' }, { '\u27f9' }, { '\u27f6' }, { '\ud835', '\udccd' },
            { '\u2a06' }, { '\u2a04' }, { '\u25b3' }, { '\u22c1' },
            { '\u22c0' }, { '\u00fd' }, { '\u00fd' }, { '\u044f' },
            { '\u0177' }, { '\u044b' }, { '\u00a5' }, { '\u00a5' },
            { '\ud835', '\udd36' }, { '\u0457' }, { '\ud835', '\udd6a' },
            { '\ud835', '\udcce' }, { '\u044e' }, { '\u00ff' }, { '\u00ff' },
            { '\u017a' }, { '\u017e' }, { '\u0437' }, { '\u017c' },
            { '\u2128' }, { '\u03b6' }, { '\ud835', '\udd37' }, { '\u0436' },
            { '\u21dd' }, { '\ud835', '\udd6b' }, { '\ud835', '\udccf' },
            { '\u200d' }, { '\u200c' }, };

    final static char[][] WINDOWS_1252 = { { '\u20AC' }, { '\uFFFD' },
            { '\u201A' }, { '\u0192' }, { '\u201E' }, { '\u2026' },
            { '\u2020' }, { '\u2021' }, { '\u02C6' }, { '\u2030' },
            { '\u0160' }, { '\u2039' }, { '\u0152' }, { '\uFFFD' },
            { '\u017D' }, { '\uFFFD' }, { '\uFFFD' }, { '\u2018' },
            { '\u2019' }, { '\u201C' }, { '\u201D' }, { '\u2022' },
            { '\u2013' }, { '\u2014' }, { '\u02DC' }, { '\u2122' },
            { '\u0161' }, { '\u203A' }, { '\u0153' }, { '\uFFFD' },
            { '\u017E' }, { '\u0178' } };

}
